@@ -1,7 +1,21 @@
+//-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 #ifndef _CONTEXT_H_
 #define _CONTEXT_H_
+#ifndef DOXYGEN_NOTFOR_DEVEL
 
 #include <string>
+namespace tlp {
+
 class Renderer;
 
 class Context {
@@ -23,4 +37,7 @@ class Context {
   Renderer& getRenderer() const;  
 };
 
+}
+
+#endif //DOXYGEN_NOTFOR_DEVEL
 #endif
