@@ -1,5 +1,17 @@
+//-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 #ifndef _DOCUMENT_H_
 #define _DOCUMENT_H_
+#ifndef DOXYGEN_NOTFOR_DEVEL
 
 #include "FLayout.h"
 #include "Context.h"
@@ -8,6 +20,8 @@
 #include <vector>
 #include <stack>
 
+namespace tlp {
+
 typedef std::vector<Frame*, std::allocator<Frame*> > VFrame; // tableau de Frames : contenu du document
 typedef std::stack<Context> SContext; // la pile de context nécessaire lors d'un ajout de frames
 typedef std::stack<Align> SAlign; // pile des alignements, dans le cas, où les <tags> sont imbriqués
@@ -35,4 +49,7 @@ class Document : public FLayout{
   bool addFrame(Frame* f);
 };
 
+}
+
+#endif //DOXYGEN_NOTFOR_DEVEL
 #endif
