@@ -1,7 +1,21 @@
+//-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 #ifndef Tulip_OCCLUSIONTEST_H
 #define Tulip_OCCLUSIONTEST_H
+#ifndef DOXYGEN_NOTFOR_DEVEL
 #include <tulip/Rectangle.h>
 
+namespace tlp {
+
 struct RectangleInt2D : public tlp::Rectangle<int> {
   RectangleInt2D(int x,int y,int x1,int y1) {
     (*this)[0][0]=x;
@@ -38,4 +52,7 @@ struct OcclusionTest {
 
 };
 
+}
+
+#endif //DOXYGEN_NOTFOR_DEVEL
 #endif
