@@ -1,5 +1,17 @@
+//-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 #ifndef _PARAGRAPH_H_
 #define _PARAGRAPH_H_
+#ifndef DOXYGEN_NOTFOR_DEVEL
 
 #include "Context.h"
 #include "Frame.h"
@@ -9,6 +21,8 @@
 
 
 
+namespace tlp {
+
 typedef enum Align{LEFT, RIGHT, CENTER, JUSTIFIED}; // défini l'alignement du texte
 
 class C_String{  // la classe utilisée pour le stockage un texte à afficher
@@ -24,7 +38,7 @@ class C_String{  // la classe utilisée pour le stockage un texte à afficher
 };
 
 
-class Paragraph : public Frame{
+class Paragraph : public Frame {
   std::vector<C_String> myString; // le texte à afficher
   std::vector<Context*> listOfcontexts; // tableau de contextes à utiliser
   Context* findContext(Context& c);  // recherche un contexte dans le vecteur
@@ -45,4 +59,7 @@ class Paragraph : public Frame{
   std::vector<C_String>* getMyString(){return &myString;}
 };
 
+}
+
+#endif //DOXYGEN_NOTFOR_DEVEL
 #endif
