@@ -1,5 +1,17 @@
+//-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 #ifndef     __TLPPixmapGlyph__
 #define     __TLPPixmapGlyph__
+#ifndef DOXYGEN_NOTFOR_DEVEL
 
 #include <ft2build.h>
 #include FT_FREETYPE_H
@@ -12,6 +24,8 @@
 #include <FTGlyph.h>
 #endif
 
+namespace tlp {
+
 /**
  * TLPPixmapGlyph is a specialisation of FTGlyph for creating pixmaps.
  * 
@@ -64,5 +78,7 @@ class  FTGL_EXPORT TLPPixmapGlyph : public FTGlyph {
         unsigned char* data;
 };
 
+}
 
+#endif //DOXYGEN_NOTFOR_DEVEL
 #endif  //  __TLPPixmapGlyph__
