@@ -1,13 +1,24 @@
-
-
-#include "tulip/Document.h"
-
+//-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 #include <iostream>
 #include <cassert>
 
-using namespace std;
+#include "tulip/Document.h"
+#include "tulip/Renderer.h"
 
-const Align DEFAULT_ALIGN=LEFT;
+using namespace std;
+using namespace tlp;
+
+const Align DEFAULT_ALIGN = LEFT;
 
 FLayout::~FLayout(){}
 Frame::~Frame(){}
@@ -69,9 +80,10 @@ Align Document::getAlign() const{
 //---------------------------------------------------------------------------
 void Document::draw(float w_max, float&w) const{
   w = 0;
-  float w_global;
+
   int n = blocks.size();
   for(int i = 0; i<n; i++){
+    float w_global = 0;
     blocks[i]->draw(w_max, w_global);
     if( w_global > w) w = w_global;
   }
