@@ -1,3 +1,14 @@
+//-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -7,26 +18,21 @@
 #include <cassert>
 
 #include "tulip/EpsFunction.h"
+#include "tulip/GlTools.h"
+
+using namespace tlp;
 
 //====================================================
-inline void SetColor(const Color &c) {
-  glColor4ub(c[0],c[1],c[2],c[3]);
-}
-
-//====================================================
-void Line(float x1,float y1,float z1,float x2, float y2 ,  float z2, Color C1, Color C2)
-{
+void tlp::Line(float x1,float y1,float z1,float x2, float y2 ,  float z2, Color C1, Color C2) {
   glBegin(GL_LINES);
-  SetColor(C1);
+  setColor(C1);
   glVertex3f(x1, y1, z1);
-  SetColor(C2);
+  setColor(C2);
   glVertex3f(x2, y2 , z2);
   glEnd();
 }
-
 //====================================================
-void Rect(float x, float y , float z, float w , float h)
-{
+void tlp::Rect(float x, float y , float z, float w , float h) {
   glBegin(GL_QUADS);
    glVertex3f(x, y , z);
    glVertex3f(x+w, y ,z);
@@ -34,7 +40,7 @@ void Rect(float x, float y , float z, float w , float h)
    glVertex3f(x, y+h , z);
   glEnd();
 }
-
+//====================================================
 static char *gouraudtriangleEPS[] =
 {
 "/bd{bind def}bind def /triangle { aload pop   setrgbcolor  aload pop 5 3",
@@ -64,21 +70,20 @@ static char *gouraudtriangleEPS[] =
 "add 3 div 10 1 roll 9 {pop} repeat 3 array astore triangle } ifelse } bd",
 NULL
 };
-
+//====================================================
 typedef struct _Feedback3Dcolor {
-GLfloat x;
-GLfloat y;
-GLfloat z;
-GLfloat red;
-GLfloat green;
-GLfloat blue;
-GLfloat alpha;
+  GLfloat x;
+  GLfloat y;
+  GLfloat z;
+  GLfloat red;
+  GLfloat green;
+  GLfloat blue;
+  GLfloat alpha;
 } Feedback3Dcolor;
-
+//====================================================
 GLfloat pointSize;
-
-GLfloat *spewPrimitiveEPS(FILE * file, GLfloat * loc)
-{
+//====================================================
+GLfloat *tlp::spewPrimitiveEPS(FILE * file, GLfloat * loc) {
   int token;
   int nvertices, i;
   GLfloat red, green, blue;
@@ -114,7 +119,7 @@ GLfloat *spewPrimitiveEPS(FILE * file, GLfloat * loc)
 
 #define Max(a,b) (((a)>(b))?(a):(b))
 
-#define EPS_SMOOTH_LINE_FACTOR 1  /* Upper for better smooth 
+#define EPS_SMOOTH_LINE_FACTOR 1  /* Upper for better smooth
 					 lines. */
       colormax = Max(absR, Max(absG, absB));
       steps =(int) rint(Max(1.0, colormax * distance * EPS_SMOOTH_LINE_FACTOR));
@@ -229,30 +234,26 @@ GLfloat *spewPrimitiveEPS(FILE * file, GLfloat * loc)
   }
   return loc;
 }
-
-
-void spewUnsortedFeedback(FILE * file, GLint size, GLfloat * buffer)
-{
+//====================================================
+void tlp::spewUnsortedFeedback(FILE * file, GLint size, GLfloat * buffer) {
   GLfloat *loc, *end;
-
   loc = buffer;
   end = buffer + size;
   while (loc < end) {
-    loc = spewPrimitiveEPS(file, loc);
+    loc = tlp::spewPrimitiveEPS(file, loc);
   }
 }
-
+//====================================================
 typedef struct _DepthIndex {
   GLfloat *ptr;
   GLfloat depth;
 } DepthIndex;
-
-int compare(const void *a, const void *b)
-{
+//====================================================
+int tlp::compare(const void *a, const void *b) {
   DepthIndex *p1 = (DepthIndex *) a;
   DepthIndex *p2 = (DepthIndex *) b;
   GLfloat diff = p2->depth - p1->depth;
-  
+
   if (diff > 0.0) {
     return 1;
   } else if (diff < 0.0) {
@@ -261,10 +262,8 @@ int compare(const void *a, const void *b)
     return 0;
   }
 }
-
-
-void spewSortedFeedback(FILE * file, GLint size, GLfloat * buffer)
-{
+//====================================================
+void tlp::spewSortedFeedback(FILE * file, GLint size, GLfloat * buffer) {
   int token;
   GLfloat *loc, *end;
   Feedback3Dcolor *vertex;
@@ -272,9 +271,9 @@ void spewSortedFeedback(FILE * file, GLint size, GLfloat * buffer)
   int nprimitives, item;
   DepthIndex *prims;
   int nvertices, i;
-  
+
   end = buffer + size;
-  
+
   /* Count how many primitives there are. */
   nprimitives = 0;
   loc = buffer;
@@ -306,14 +305,14 @@ void spewSortedFeedback(FILE * file, GLint size, GLfloat * buffer)
 	     token);
     }
   }
-  
+
   /* Allocate an array of pointers that will point back at
      primitives in the feedback buffer.  There will be one
      entry per primitive.  This array is also where we keep the
      primitive's average depth.  There is one entry per
      primitive  in the feedback buffer. */
   prims = (DepthIndex *) malloc(sizeof(DepthIndex) * nprimitives);
-  
+
   item = 0;
   loc = buffer;
   while (loc < end) {
@@ -350,43 +349,43 @@ void spewSortedFeedback(FILE * file, GLint size, GLfloat * buffer)
     case GL_PASS_THROUGH_TOKEN:
       loc++;
       break;
-      
+
     default:
       /* XXX Left as an excersie to the reader. */
       return;
     }
   }
   assert(item == nprimitives);
-  
+
   /* Sort the primitives back to front. */
   qsort(prims, nprimitives, sizeof(DepthIndex), compare);
-  
+
   /* Understand that sorting by a primitives average depth
      doesn't allow us to disambiguate some cases like self
      intersecting polygons.  Handling these cases would require
      breaking up the primitives.  That's too involved for this
      example.  Sorting by depth is good enough for lots of
      applications. */
-  
+
   /* Emit the Encapsulated PostScript for the primitives in
      back to front order. */
   for (item = 0; item < nprimitives; item++) {
     (void) spewPrimitiveEPS(file, prims[item].ptr);
   }
-  
+
   free(prims);
 }
-
-#define EPS_GOURAUD_THRESHOLD 0.5  /* Lower for better (slower) 
+//====================================================
+#define EPS_GOURAUD_THRESHOLD 0.5  /* Lower for better (slower)
 
 smooth shading. */
 
-void spewWireFrameEPS(FILE * file, int doSort, GLint size, GLfloat * buffer, char *creator)
-{
+void tlp::spewWireFrameEPS(FILE * file, int doSort, GLint size, GLfloat * buffer, char *creator) {
+
   GLfloat clearColor[4], viewport[4];
   GLfloat lineWidth;
   int i;
-  
+
   /* Read back a bunch of OpenGL state to help make the EPS
      consistent with the OpenGL clear color, line width, point
      size, and viewport. */
@@ -394,7 +393,7 @@ void spewWireFrameEPS(FILE * file, int doSort, GLint size, GLfloat * buffer, cha
   glGetFloatv(GL_COLOR_CLEAR_VALUE, clearColor);
   glGetFloatv(GL_LINE_WIDTH, &lineWidth);
   glGetFloatv(GL_POINT_SIZE, &pointSize);
-  
+
   /* Emit EPS header. */
   fputs("%!PS-Adobe-2.0 EPSF-2.0\n", file);
   /* Notice %% for a single % in the fprintf calls. */
@@ -404,7 +403,7 @@ void spewWireFrameEPS(FILE * file, int doSort, GLint size, GLfloat * buffer, cha
   fputs("\n", file);
   fputs("gsave\n", file);
   fputs("\n", file);
-  
+
   /* Output Frederic Delhoume's "gouraudtriangle" PostScript
      fragment. */
   fputs("% the gouraudtriangle PostScript fragement below is free\n", file);
@@ -413,9 +412,9 @@ void spewWireFrameEPS(FILE * file, int doSort, GLint size, GLfloat * buffer, cha
   for (i = 0; gouraudtriangleEPS[i]; i++) {
     fprintf(file, "%s\n", gouraudtriangleEPS[i]);
   }
-  
+
   fprintf(file, "\n%g setlinewidth\n", lineWidth);
-  
+
   /* Clear the background like OpenGL had it. */
   //  fprintf(file, "%g %g %g setrgbcolor\n",
   //	  clearColor[0], clearColor[1], clearColor[2]);
@@ -423,29 +422,27 @@ void spewWireFrameEPS(FILE * file, int doSort, GLint size, GLfloat * buffer, cha
 	  1.0 , 1.0 , 1.0);
   fprintf(file, "%g %g %g %g rectfill\n\n",
 	  viewport[0], viewport[1], viewport[2], viewport[3]);
-  
-  if (doSort) 
+
+  if (doSort)
     {
       spewSortedFeedback(file, size, buffer);
-    } 
+    }
   else
     {
       spewUnsortedFeedback(file, size, buffer);
     }
-  
+
   /* Emit EPS trailer. */
   fputs("grestore\n\n", file);
   fputs("%Add `showpage' to the end of this file to be able to print to a printer.\n",
 	file);
-  
+
   fclose(file);
 }
-
+//====================================================
 /* Write contents of one vertex to stdout. */
-void print3DcolorVertex(GLint size, GLint * count, GLfloat * buffer)
-{
+void tlp::print3DcolorVertex(GLint size, GLint * count, GLfloat * buffer) {
   int i;
-  
   printf("  ");
   for (i = 0; i < 7; i++) {
     printf("%4.2f ", buffer[size - (*count)]);
@@ -453,9 +450,8 @@ void print3DcolorVertex(GLint size, GLint * count, GLfloat * buffer)
   }
   printf("\n");
 }
-
-void printBuffer(GLint size, GLfloat * buffer)
-{
+//====================================================
+void tlp::printBuffer(GLint size, GLfloat * buffer) {
   GLint count;
   int token, nvertices;
 
@@ -493,3 +489,4 @@ void printBuffer(GLint size, GLfloat * buffer)
     }
   }
 }
+//====================================================
