@@ -1,54 +1,42 @@
+//-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 #include <cmath>
 #include <tulip/Size.h>
 #include <tulip/Coord.h>
 #include <tulip/Glyph.h>
 
+using namespace tlp;
+using namespace std;
+
+TemplateFactory<GlyphFactory,Glyph, GlyphContext *> *GlyphFactory::factory;
+
 Glyph::Glyph(GlyphContext *gc) {
-  if (gc!=NULL) {
-    superGraph=gc->superGraph;
-    glGraph=gc->glGraph;
-    LOF=gc->LOF;
-    LOD=gc->LOD;
+  if (gc != 0) {
+    glGraphInputData=gc->glGraphInputData;
   }
   else {
-    superGraph = NULL;
-    glGraph = NULL;
-    LOD=LOF=0;
+    glGraphInputData = 0;
   }
 }
-
+//=============================================
 Glyph::~Glyph() {
 }
-
-void Glyph::setLOF(int n) {
-  LOF = ((n<0) ? 0 : ((n > 10) ? 10 : n));
-}
-
-int Glyph::getLOF() {return LOF;}
-
-void Glyph::setLOD(int n) {
-  LOD = ((n<0) ? 0 : ((n > 10) ? 10 : n));
-}
-
-int Glyph::getLOD() {
-  return LOD;
-}
-
-void Glyph::setMaterial(const Color &C) {
-  float color[4] = { 0.0, 0.0, 0.0, 1.0 };
-  color[0]=((float)C.getR())/255;
-  color[1]=((float)C.getG())/255;
-  color[2]=((float)C.getB())/255;
-  glMaterialfv(GL_FRONT, GL_AMBIENT_AND_DIFFUSE, color);
-}
-
+//=============================================
 Coord Glyph::getAnchor(const Coord &nodeCenter, const Coord &from, const Size &scale, const double zRotation) const {
   Coord anchor = from - nodeCenter;
   if( anchor.getX() == 0.0f && anchor.getY() == 0.0f && anchor.getZ() == 0.0f )
     return nodeCenter;
-  if( scale.getW() == 0.0f || scale.getH() == 0.0f || scale.getD() == 0.0f )
-    return nodeCenter;
-
+  /*if( scale.getW() == 0.0f || scale.getH() == 0.0f || scale.getD() == 0.0f )
+    return nodeCenter;*/
 
   //unrotate
   Coord saveAnchor(anchor);
@@ -59,17 +47,21 @@ Coord Glyph::getAnchor(const Coord &nodeCenter, const Coord &from, const Size &s
   // unscale
   anchor.setX( anchor.getX() / scale.getW() );
   anchor.setY( anchor.getY() / scale.getH() );
-  anchor.setZ( anchor.getZ() / scale.getD() );
-  
-  anchor = getAnchor( anchor );
-  
+  if(scale.getD() != 0.0f)
+    anchor.setZ( anchor.getZ() / scale.getD() );
+  else
+    anchor.setZ(0.0f);
 
+  anchor = getAnchor( anchor );
 
   // rescale
   anchor.setX( anchor.getX() * scale.getW() );
   anchor.setY( anchor.getY() * scale.getH() );
   anchor.setZ( anchor.getZ() * scale.getD() );
 
+  if(scale.getD() == 0.0f)
+    anchor[2]=0.;
+
   //rerotate
   saveAnchor = anchor;
   zRot = -zRot;
@@ -78,7 +70,7 @@ Coord Glyph::getAnchor(const Coord &nodeCenter, const Coord &from, const Size &s
 
   return nodeCenter + anchor;
 }
-
+//=================================================================
 Coord Glyph::getAnchor(const Coord &vector) const
 {
   Coord anchor = vector;
