@@ -1,6 +1,19 @@
+//-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 #include "tulip/Hline.h"
 #include "tulip/Renderer.h"
 
+using namespace tlp;
+
 const int HAUTEUR=5; // défini l'espace avant et après la ligne horizontale
 
 void Hline::draw(float w_max, float& w)const{
