@@ -1,3 +1,14 @@
+//-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 #include "tulip/Paragraph.h"
 #include "tulip/Renderer.h"
 
@@ -9,6 +20,7 @@
 #define H 3
 
 using namespace std;
+using namespace tlp;
 
 //***************************************************************************
 // CLASSE C_String
@@ -31,32 +43,30 @@ Paragraph::~Paragraph(){
     delete listOfcontexts[i];
   }
 }
-
 //---------------------------------------------------------------------------
 void Paragraph::drawLeft(float w_max, float x_depl, int debut, int fin) const{
-  int j, val;
-  float decal= 0;
-  Context* c_current;
+  int val;
+  float decal = 0;
 
-  for(j = debut; j<=fin; j++){  // on affiche chaque mot sur la ligne
-    c_current = myString.at(j).getContext();
+  for(int j = debut; j<=fin; ++j){  // on affiche chaque mot sur la ligne
+    Context* c_current = myString.at(j).getContext();
     Renderer &renderer = c_current->getRenderer();
     val = renderer.searchFont(renderer.getMode(), c_current->getSize(),c_current->getFontName(), renderer.getDepth());
     assert(val != -1);
-    
+
     unsigned char r, v, b;
     c_current->getColor(r, v, b);
     renderer.setColor(r, v, b);
-    
     renderer.ActiveFont(val);
+
     if(myString.at(j).getString() != ""){
        renderer.drawString(myString.at(j).getString());
-       decal = renderer.getAdvance(myString.at(j).getString().c_str());
+       decal = renderer.getAdvance(myString.at(j).getString());
+       renderer.translate(-decal, 0, 0);
     }
-    renderer.translate(decal, 0, 0);
-  }      
-}
 
+  }
+}
 //---------------------------------------------------------------------------
 void Paragraph::drawRight(float w_max, float x_depl, int debut, int fin) const{
   int j, val;
@@ -70,11 +80,11 @@ void Paragraph::drawRight(float w_max, float x_depl, int debut, int fin) const{
 
     val = renderer.searchFont(renderer.getMode(), c_current->getSize(), c_current->getFontName(), renderer.getDepth());
     assert(val != -1);
-    
+
     unsigned char r, v, b;
     c_current->getColor(r, v, b);
     renderer.setColor(r, v, b);
-    
+
     renderer.ActiveFont(val);
     if(myString.at(j).getString() != ""){
       renderer.drawString(myString.at(j).getString());
@@ -85,7 +95,6 @@ void Paragraph::drawRight(float w_max, float x_depl, int debut, int fin) const{
       renderer.translate(-(w_max - x_depl), 0, 0);
   }
 }
-
 //---------------------------------------------------------------------------
 void Paragraph::drawCenter(float w_max, float x_depl, int debut, int fin) const{
   int j, val;
@@ -100,7 +109,7 @@ void Paragraph::drawCenter(float w_max, float x_depl, int debut, int fin) const{
     unsigned char r, v, b;
     c_current->getColor(r, v, b);
     renderer.setColor(r, v, b);
-    
+
     renderer.ActiveFont(val);
     if(myString.at(j).getString() != ""){
       renderer.drawString(myString.at(j).getString());
@@ -128,13 +137,15 @@ void Paragraph::draw(float w_max, float& w) const{
     Renderer &renderer = c_current->getRenderer();
     // recherche de la police
     val = renderer.searchFont(renderer.getMode(), c_current->getSize(), c_current->getFontName(), renderer.getDepth());
-    if(val == -1) // jout de la police si elle n'existe pas
+    if(val == -1) // ajout de la police si elle n'existe pas
       val = renderer.AddFont(renderer.getMode(), c_current->getSize(), c_current->getFontName(), renderer.getDepth());
+    if(val == -1)
+      return;
     s = myString.at(i).getString(); // on récupère le mot;
-    
+
     if(s != ""){
       cumul_s += renderer.getAdvance(s.c_str(), val); // on recherche sa longueur
-            
+
       int length_s = s.size();
       if(s[length_s-1] == ' ')
 	do_test = true;
@@ -145,7 +156,7 @@ void Paragraph::draw(float w_max, float& w) const{
     }
     else
       do_test = true;
-      
+
     if(HeightSup<renderer.getAscender(val))
       HeightSup = renderer.getAscender(val);
     if(HeightInf<fabs(renderer.getDescender(val)))
@@ -159,10 +170,10 @@ void Paragraph::draw(float w_max, float& w) const{
 	x_depl += size_s;
       }
       else{
-	renderer.translate(0,-(maxHeightSup),0); 
+	renderer.translate(0,-(maxHeightSup),0);
 	float sav_inf = maxHeightInf;
 	maxHeightSup =  HeightSup;
-	maxHeightInf =  HeightInf;      
+	maxHeightInf =  HeightInf;
 	switch(alignement){
 	case LEFT:      drawLeft(w_max, x_depl, i_deb, i-taille);   break;
 	case RIGHT:     drawRight(w_max, x_depl, i_deb, i-taille);  break;
@@ -170,8 +181,9 @@ void Paragraph::draw(float w_max, float& w) const{
 	case JUSTIFIED: drawLeft(w_max, x_depl, i_deb, i-taille); // A FAIRE       !!!!!!!!!!!!!!!!!!!!!!!!!!!
 	}
 	// retour à la ligne
-	renderer.translate(-x_depl,-(sav_inf+H),0);
-	if(x_depl > w) w = x_depl;	
+	// renderer.translate(-x_depl,-(sav_inf+H),0);
+	renderer.translate(0,-(sav_inf+H),0);
+	if(x_depl > w) w = x_depl;
 	i_deb = i-taille+1; // maj du valeur
 	x_depl = size_s;
       }
@@ -181,19 +193,19 @@ void Paragraph::draw(float w_max, float& w) const{
       HeightInf = 0;
     }
   }
-  
+
   // derniere ligne à afficher ou première s'il y en a eu qu'une ...
   _context.getRenderer().translate(0,-(maxHeightSup),0);
-  
+
   switch(alignement){
   case LEFT:      drawLeft(w_max, x_depl, i_deb, n-1);    break;
   case RIGHT:     drawRight(w_max, x_depl, i_deb, n-1);   break;
   case CENTER:    drawCenter(w_max, x_depl, i_deb, n-1);  break;
   case JUSTIFIED: drawLeft(w_max, x_depl, i_deb, i-1); // A FAIRE         !!!!!!!!!!!!!!!!!!!!!!!!!!!
   }
-  
+
   // retour à la ligne
-  _context.getRenderer().translate(-x_depl,-(maxHeightInf+H),0);
+  _context.getRenderer().translate(0 ,-(maxHeightInf+H),0);
   if(x_depl > w) w = x_depl;
 }
 
@@ -217,7 +229,8 @@ void Paragraph::getBoundingBox(float w_max, float& h, float& w) const{
     val = renderer.searchFont(renderer.getMode(), c_current->getSize(), c_current->getFontName(), renderer.getDepth());
     if(val == -1) // ajoute de la police si elle n'existe pas
       val = renderer.AddFont(renderer.getMode(), c_current->getSize(), c_current->getFontName(), renderer.getDepth());
-    if (val == -1) {cerr << __PRETTY_FUNCTION__ << " ==> Add font failed" << endl;return;}
+    if (val == -1)
+      return;
     s = myString.at(i).getString(); // on récupère le mot;
     if(s != ""){
       cumul_s += renderer.getAdvance(s.c_str(), val); // on recherche sa longueur
@@ -229,12 +242,12 @@ void Paragraph::getBoundingBox(float w_max, float& h, float& w) const{
       }
     }
     else
-      do_test = true;    
+      do_test = true;
     if(HeightSup<renderer.getAscender(val))
       HeightSup = renderer.getAscender(val);
     if(HeightInf<fabs(renderer.getDescender(val)))
       HeightInf = fabs(renderer.getDescender(val));
-    
+
     if(do_test){
       size_s = cumul_s;
       if((x_depl + size_s <= w_max) && (s != "")){ // test si la longeur cumulée va dépasser
@@ -244,9 +257,9 @@ void Paragraph::getBoundingBox(float w_max, float& h, float& w) const{
 
       }
       else{
-	h += maxHeightSup+maxHeightInf+H; 
+	h += maxHeightSup+maxHeightInf+H;
 	maxHeightSup = HeightSup;
-	maxHeightInf = HeightInf;      
+	maxHeightInf = HeightInf;
 	if(x_depl > w) w = x_depl;
 	i_deb = i-taille+1; // maj du valeur
 	x_depl = size_s;
@@ -258,13 +271,13 @@ void Paragraph::getBoundingBox(float w_max, float& h, float& w) const{
     }
   }
   // derniere ligne à afficher ou première s'il y en a eu qu'une ...
-  h += maxHeightSup+maxHeightInf+H; 
-  if(x_depl > w) w = x_depl; 
+  h += maxHeightSup+maxHeightInf+H;
+  if(x_depl > w) w = x_depl;
 }
 //---------------------------------------------------------------------------
 bool Paragraph::addString(string s, Context c){
   Context* ctr;
-  ctr = findContext(c); 
+  ctr = findContext(c);
   if(!ctr) {
     ctr = new Context(c);
     listOfcontexts.push_back(ctr);
@@ -281,4 +294,4 @@ Context* Paragraph::findContext(Context& c){
       return listOfcontexts[i];
   }
   return 0;
-} 
+}
