@@ -1,3 +1,14 @@
+//-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 #include "tulip/Context.h"
 #include "tulip/Table.h"
 #include "tulip/Renderer.h"
@@ -5,6 +16,7 @@
 #include <cassert>
 #include <iostream>
 using namespace std;
+using namespace tlp;
 
 const int H = 10;
 
