@@ -1,3 +1,14 @@
+//-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 //@TLPGEOLICENCE#
 
 #ifndef _TLP_GEO_ARRAY_H
@@ -6,9 +17,9 @@
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
-#include <tulip/tulipconf.h>
 #include <cassert>
 #include <iostream>
+#include <tulip/tulipconf.h>
 
 namespace tlp {
   /**
@@ -19,14 +30,14 @@ namespace tlp {
    * \brief class for array encapsulation
    *
    * Enables to create an Array of Obj with a
-   * Fixed size, limit of the array are checked only
+   * limited size. Out of bound accesses are only checked
    * in debug mode.
    * 
    * \author : David Auber auber@tulip-software.org
    * \version 0.0.1 24/01/2003 
    */
   template <typename Obj,unsigned int SIZE>
-  struct TLP_SCOPE Array {
+  struct Array {
     Obj array[SIZE];
     inline Obj  operator[](const unsigned int i) const;
     inline Obj& operator[](const unsigned int i);
