@@ -1,8 +1,9 @@
 //-*-c++-*-
-/*
- Author: Romain BOURQUI
- Email : bourqui@labri.fr
- Last modification : 02/11/2005
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by  
  the Free Software Foundation; either version 2 of the License, or     
@@ -13,22 +14,25 @@
 //#define Bfs_H
 
 #include <tulip/MutableContainer.h>
+#include <tulip/Graph.h>
 
+namespace tlp {
 class TLP_SCOPE Bfs {
  public :
   
-  Bfs(SuperGraph * G, SelectionProxy * resultatAlgoSelection);
+  Bfs(Graph * G, BooleanProperty* resultatAlgoSelection);
   ~Bfs();
 
-  SuperGraph * graph;
+  Graph *graph;
 
  private :
 
-  void computeBfs(SuperGraph * G,SelectionProxy * resultatAlgoSelection, node root);  
+  void computeBfs(Graph * G, BooleanProperty* resultatAlgoSelection, node root);  
 
-  SelectionProxy * s_proxy;
+  BooleanProperty* s_proxy;
   unsigned int nbNodes;
   MutableContainer<bool>::MutableContainer selectedNodes;
   MutableContainer<bool>::MutableContainer selectedEdges;
 
  };  
+}
