@@ -1,3 +1,14 @@
+//-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 /*
  * Authors: Jrmy Compostella, Jean Darracq, Benjamin Muller,
  *          Fabrice Rochambeau, Fabiani Simplice, Jyl Cristoff Zobeide
@@ -19,8 +30,6 @@
 
 #ifndef DOXYGEN_NOTFOR_USER
 
-#include <tulip/TlpTools.h>
-
 template <typename TYPE> struct BmdList;
 template <typename TYPE> struct BmdListTest;
 
@@ -40,7 +49,7 @@ namespace tlp {
     BmdLink *succ(){
       return suc;
     }
-  protected:
+    //protected:
     TYPE data;
     BmdLink *pre;
     BmdLink *suc;
