@@ -1,8 +1,9 @@
 //-*-c++-*-
-/*
- Author: David Auber
- Email : auber@labri.fr
- Last modification : 10/05/2003
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by  
  the Free Software Foundation; either version 2 of the License, or     
@@ -17,6 +18,8 @@
  * The iterators given in parameter will be automatically
  * delete when the iterator will be deleted.
  */
+namespace tlp {
+
 template<class itType> struct ConcatIterator : public Iterator<itType> {
   ConcatIterator(Iterator<itType> *itOne,Iterator<itType> *itTwo) : 
     itOne(itOne),
@@ -42,4 +45,5 @@ template<class itType> struct ConcatIterator : public Iterator<itType> {
   Iterator<itType> *itTwo;
 };
 
+}
 #endif
