@@ -1,9 +1,21 @@
+//-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 #ifndef TLP_GEO_CONVEX_HULL_H
 #define TLP_GEO_CONVEX_HULL_H
 #include <vector>
 #include <tulip/Coord.h>
 
 namespace tlp {
+
   /**
    * \addtogroup basic
    */ 
@@ -23,8 +35,8 @@ namespace tlp {
    * points on the convex hull in counterclockwise order.  The convexHull
    * vector is automatically cleared.  The algorithm runs in O(nlgn) time.
    */
-  void convexHull (const std::vector<Coord> &points, 
-		   std::vector<unsigned int> &convexHull);
+  TLP_SCOPE void convexHull (const std::vector<Coord> &points, 
+			     std::vector<unsigned int> &convexHull);
 
   /**
    * Merges two convex hulls hull1 and hull2 using the rotating calipers
@@ -37,10 +49,10 @@ namespace tlp {
    * indexes into points of the verticies on the merged convex hull are 
    * returned in the vector mergedConvexHull.
    */
-  void mergeHulls (const std::vector<Coord> &points,
-		   const std::vector<unsigned int> &hull1,
-		   const std::vector<unsigned int> &hull2,
-		   std::vector<unsigned int> &mergedConvexHull);
+  TLP_SCOPE void mergeHulls (const std::vector<Coord> &points,
+			     const std::vector<unsigned int> &hull1,
+			     const std::vector<unsigned int> &hull2,
+			     std::vector<unsigned int> &mergedConvexHull);
 
   /**
    * Intersects two convex hulls using the algorithm of
@@ -56,26 +68,27 @@ namespace tlp {
    * be inserted into the "points" list.  These points correspond to the
    * points generated when edges of hull1 and hull2 intersect.
    */
-  void intersectHulls (std::vector<Coord> &points,
-		       const std::vector<unsigned int> &hull1,
-		       const std::vector<unsigned int> &hull2,
-		       std::vector<unsigned int> &intersection);
+  TLP_SCOPE void intersectHulls (std::vector<Coord> &points,
+				 const std::vector<unsigned int> &hull1,
+				 const std::vector<unsigned int> &hull2,
+				 std::vector<unsigned int> &intersection);
 
   /**
    * Computes the area of the convex "hull" which is a list of indexes
    * into the vector of Coord "points".
    */
-  double areaOfHull (const std::vector<Coord> &points,
-		     const std::vector<unsigned int> &hull);
+  TLP_SCOPE double areaOfHull (const std::vector<Coord> &points,
+			       const std::vector<unsigned int> &hull);
   
   /**
    * Returns true if "point" is inside "hull".  Hull is a list of
    * indexes into the vector of Coord "points."
    */
-  bool insideHull (const std::vector<Coord> &points,
-		   const std::vector<unsigned int> &hull,
-		   const Coord &point);
+  TLP_SCOPE bool insideHull (const std::vector<Coord> &points,
+			     const std::vector<unsigned int> &hull,
+			     const Coord &point);
   
   /*@}*/
+
 }
 #endif
