@@ -1,8 +1,9 @@
 //-*-c++-*-
-/*
- Author: Romain BOURQUI
- Email : bourqui@labri.fr
- Last Version : 10/01/2006
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by  
  the Free Software Foundation; either version 2 of the License, or     
@@ -11,7 +12,7 @@
 
 #ifndef Tulip_FACE_H
 #define Tulip_FACE_H
-#include "tulipconf.h"
+#include "tulip/tulipconf.h"
 #if (__GNUC__ < 3)
 #include <hash_map>
 #else
@@ -20,8 +21,10 @@
 #include <climits>
 
 /**
- * \defgroup graphs
+ * \addtogroup graphs
  */ 
+namespace tlp {
+
 /*@{*/
 /// class face
 struct Face { 
@@ -33,21 +36,22 @@ struct Face {
   bool isValid() const {return id!=UINT_MAX;}
 };
 /*@}*/
+}
 
 #ifndef DOXYGEN_NOTFOR_DEVEL
 
 namespace stdext {
-  template<> struct hash<Face> {
-    size_t operator()(const Face f) const {return f.id;}
+  template<> struct hash<tlp::Face> {
+    size_t operator()(const tlp::Face f) const {return f.id;}
   };
 }
 
 namespace std {
-  template<> struct equal_to<Face> {
-    size_t operator()(const Face f,const Face f2) const {return f.id == f2.id;}
+  template<> struct equal_to<tlp::Face> {
+    size_t operator()(const tlp::Face f,const tlp::Face f2) const {return f.id == f2.id;}
   };
-  template<> struct less<Face>{
-    size_t operator()(const Face f,const Face f2) const {return f.id < f2.id;}
+  template<> struct less<tlp::Face>{
+    size_t operator()(const tlp::Face f,const tlp::Face f2) const {return f.id < f2.id;}
   };
 }
 #endif // DOXYGEN_NOTFOR_DEVEL
