@@ -1,8 +1,9 @@
 //-*-c++-*-
-/*
- Author: David Auber
- Email : auber@labri.fr
- Last modification : 10/01/2006
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by  
  the Free Software Foundation; either version 2 of the License, or     
@@ -13,7 +14,9 @@
 
 #include <assert.h>
 #include <tulip/Iterator.h>
+#include <tulip/StableIterator.h>
 
+#ifndef DOXYGEN_NOTFOR_DEVEL
 namespace tlp {
   template<typename TYPE>
   struct _TLP_IT {
@@ -37,8 +40,14 @@ namespace tlp {
     return (void *)new _TLP_IT<TYPE>(n, _it, (void (*) (void *)) &_tlp_delete_it<TYPE>);
   }
 
+  template <typename TYPE>
+  inline void * _tlp_get_stable_it(TYPE &n, Iterator<TYPE> *_it) {
+    return (void *)new _TLP_IT<TYPE>(n, new StableIterator<TYPE>(_it),
+				     (void (*) (void *)) &_tlp_delete_it<TYPE>);
+  }
+
   template<typename TYPE>
-  inline bool _tlp_if_test(TYPE &n, void *_it) {
+  inline bool _tlp_if_test(TYPE &, void *_it) {
     assert(((_TLP_IT<TYPE>*)_it)->_it !=0);
     if(((_TLP_IT<TYPE>*)_it)->_it->hasNext()) {
       ((_TLP_IT<TYPE>*)_it)->_n = ((_TLP_IT<TYPE>*)_it)->_it->next(); 
@@ -50,15 +59,19 @@ namespace tlp {
     }
   }
 }
+#endif //DOXYGEN_NOTFOR_DEVEL
 
 
 /**
  * Warning, do not use break or return inside a for each block;
- * it causes a memory leak.
+ * it causes a memory leak; use breakForEach pr returnForEachInstead
  */
 #define forEach(A, B) \
   for(void *_it_foreach = tlp::_tlp_get_it(A, B); tlp::_tlp_if_test(A, _it_foreach);)
 
+#define stableForEach(A, B)  \
+  for(void *_it_foreach = tlp::_tlp_get_stable_it(A, B); tlp::_tlp_if_test(A, _it_foreach);)
+
 #define _delete_it_foreach ((**((void (**) (void *)) _it_foreach))(_it_foreach))
 
 #define breakForEach {_delete_it_foreach; break;}
