@@ -1,19 +1,23 @@
 //-*-c++-*-
-/*
- Author: David Auber
- Email : auber@labri.fr
- Last modification : 20/08/2001
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by  
  the Free Software Foundation; either version 2 of the License, or     
  (at your option) any later version.
 */
+#ifndef DOXYGEN_NOTFOR_DEVEL
 
 #ifndef _TULIPIDMANAGER_H
 #define _TULIPIDMANAGER_H
 #include <set>
 #include <iostream>
-#include "Iterator.h"
+#include "tulip/Iterator.h"
+
+namespace tlp {
 
 class IdManagerIterator;
 
@@ -23,7 +27,7 @@ class IdManager {
 public:
   IdManager();
   /**
-   * Return true if the id is not used else false.
+   * Returns true if the id is not used else false.
    */
   bool is_free(unsigned int) const;
   /**
@@ -31,26 +35,26 @@ public:
    */
   void free(const unsigned int);
   /**
-   * Return a new id, the returned id is choosen to minimize
+   * Returns a new id, the returned id is choosen to minimize
    * the memory space of the free list, and the fragmetation
    * of the ids.
    */
   unsigned int get();
   /**
-   * Return an iterator on all the used id. Warning, if
+   * Returns an iterator on all the used ids. Warning, if
    * the idManager is modified (free, get) this iterator 
    * will be invalidate.
    */
-  Iterator<unsigned int>* getUsedId() const;
-  
+  Iterator<unsigned int>* getIds() const;
+
   friend std::ostream& operator<<(std::ostream &,const IdManager &);
   friend class IdManagerIterator;
   friend class IdManagerTest;
 
-private:
+  private:
   std::set<unsigned int> freeIds;  
-  unsigned int maxId;
-  unsigned int minId;
+  unsigned int nextId;
+  unsigned int firstId;
 };
 //======================================================
 /// Iterator for id managers
@@ -62,12 +66,16 @@ public:
   unsigned int next();
   bool hasNext();
 private:
-  unsigned int index;
+  unsigned int current;
   std::set<unsigned int>::const_iterator it;
-  const IdManager &idMan;
+  unsigned int last;
+  const IdManager &idManager;
 };
 #endif
 //======================================================
 std::ostream& operator<<(std::ostream &,const IdManager &);
 
+}
+
 #endif
+#endif //DOXYGEN_NOTFOR_DEVEL
