@@ -1,3 +1,14 @@
+//-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 #ifndef OBSERVABLE_H
 #define OBSERVABLE_H
 
@@ -7,18 +18,20 @@
 
 #include <tulip/tulipconf.h>
 
-#include <list>
+#include <ext/slist>
 #include <map>
 #include <set>
 
+namespace tlp {
+
 class Observable;
 
 //=========================================================
 /**
- * The Observer pattern is described in the lecture notes and pp293-304 
- * of Design Patterns by Gamma, Helm, Johnson, and Vlissides. It is a 
+ * The Observer pattern is a 
  * framework for handling state dependency between observer and observed 
- * object.
+ * object. It is described in the lecture notes and pp293-304 
+ * of Design Patterns by Gamma, Helm, Johnson, and Vlissides.
  */
 class Observer {
  public:
@@ -41,10 +54,9 @@ class Observer {
 typedef std::map<Observer *,std::set<Observable *> > ObserverMap;
 
 //=========================================================
-/**Toutes les instance de cette classe peuvent tre observer 
- *par une instance de la classe Observer. 
- *@see Observer
- */
+/** All instances of that class can be observed by by an instance of the
+  * Observer class. 
+  */
 class TLP_SCOPE Observable {
  public:
   virtual ~Observable() {}
@@ -53,17 +65,17 @@ class TLP_SCOPE Observable {
    */
   void addObserver(Observer *);
   /**
-   * Return the number of observers
+   * Returns the number of observers
    */
   unsigned int countObservers();
   /**
    * Remove an observer
    */
-  void deleteObserver(Observer *);
+  void removeObserver(Observer *);
   /**
    * Remove all observers
    */
-  void deleteObservers();
+  void removeObservers();
   /**
    * Notify all the observers
    */
@@ -85,26 +97,28 @@ class TLP_SCOPE Observable {
  protected:
   static int holdCounter;
   static ObserverMap holdMap;
-  std::list<Observer*> observersList;
+  stdext::slist<Observer*> observersList;
 };
 
 
 inline void Observable::addObserver(Observer *obs) {
-  observersList.push_back(obs); 
+  observersList.push_front(obs);
 }
 
 inline unsigned int Observable::countObservers() { 
   return observersList.size(); 
 }
 
-inline void Observable::deleteObserver(Observer *item) {  
+inline void Observable::removeObserver(Observer *item) {  
   observersList.remove(item);
 }
 
-inline void Observable::deleteObservers() { 
+inline void Observable::removeObservers() { 
   observersList.clear(); 
 }
 
+}
+
 #endif
 
 
