@@ -1,8 +1,9 @@
 //-*-c++-*-
-/*
- Author: David Auber
- Email : auber@labri.fr
- Last modification : 20/08/2001
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by  
  the Free Software Foundation; either version 2 of the License, or     
@@ -12,44 +13,48 @@
 #ifndef _PLUGINCONTEXT
 #define _PLUGINCONTEXT
 
-#include "Reflect.h"
+#include "tulip/Reflect.h"
 
-class SuperGraph;
-class PProxy;
+namespace tlp {
+
+class Graph;
+class PropertyInterface;
 class PluginProgress;
-///Parameter for calling clustering plugins
 
 /**
  * \defgroup plugins
  */ 
 /*@{*/
 
-class ClusterContext {
+///Parameter for calling clustering plugins
+class AlgorithmContext {
   public :
   ///
-  SuperGraph *superGraph;
+  Graph *graph;
   PluginProgress *pluginProgress;
   DataSet *dataSet;
   ///
-  ClusterContext ():superGraph(0),pluginProgress(0), dataSet(0) {}
+  AlgorithmContext ():graph(0),pluginProgress(0), dataSet(0) {}
   ///
-  ~ClusterContext(){}
+  ~AlgorithmContext(){}
 };
 
 ///Parameter for calling Property plugins
 class PropertyContext {
   public :
   ///
-  SuperGraph *superGraph;
-  PProxy *propertyProxy;
+  Graph *graph;
+  PropertyInterface *propertyProxy;
   PluginProgress *pluginProgress;
   DataSet *dataSet;
   ///
-  PropertyContext ():superGraph(0),propertyProxy(0),pluginProgress(0),dataSet(0){}
+  PropertyContext ():graph(0),propertyProxy(0),pluginProgress(0),dataSet(0){}
   ///
   ~PropertyContext(){}
 };
 /*@}*/
+
+}
 #endif
 
 
