@@ -1,16 +1,16 @@
 //-*-c++-*-
-/*
- Author: Delorme Maxime
- Email : Maxime.Delorme@gmail.com
-
- Last modification : 23/07/2005 (fr) 
-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by  
  the Free Software Foundation; either version 2 of the License, or     
  (at your option) any later version.
 */
 
+#ifndef DOXYGEN_NOTFOR_DEVEL
 #ifndef TLP_POLYNOME_H
 #define TLP_POLYNOME_H
 
@@ -51,3 +51,4 @@ class Polynome
 };
 }
 #endif
+#endif //DOXYGEN_NOTFOR_DEVEL
