@@ -1,3 +1,14 @@
+//-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 #ifndef _TULIPREFLECT
 #define _TULIPREFLECT
 
@@ -9,28 +20,38 @@
 #include <string>
 #include <cassert>
 #include <typeinfo>
-#include "StlIterator.h"
+#include <list>
+#include "tulip/StlIterator.h"
 
+namespace tlp {
 
-struct SuperGraph;
+struct Graph;
 
+ struct TLP_SIMPLE_SCOPE DataMem {
+   DataMem(){}
+   virtual ~DataMem() {};
+ };
 
-struct TLP_SIMPLE_SCOPE DataType {
-  DataType(){}
-  DataType(void *value,const std::string typeName):value(value),typeName(typeName){}
-  void * value;
-  std::string typeName;
-};
+ struct TLP_SIMPLE_SCOPE DataType :public DataMem {
+   DataType(){}
+   DataType(void *value,const std::string typeName):value(value),typeName(typeName){}
+   virtual DataType *clone() = 0;
+   void *value;
+   std::string typeName;
+ };
 
-
-/*!  A container which allows insertion of different type.
+/*!  A container which allows insertion of different types.
      The inserted data must have a copy-constructor well done */
 struct TLP_SIMPLE_SCOPE DataSet {
-  /** Return a copy of the value of the variable with name str.
+  DataSet() {}
+  DataSet(const DataSet &set);
+  DataSet& operator=(const DataSet &set);
+  ~DataSet();
+  /** Returns a copy of the value of the variable with name str.
      Type are checked in Debug Mode.
      If the variable str doesn't exist return false else true. */
-  template<typename T> bool get(const std::string str, T& value) const;
-  /** Return a copy of the value of the variable with name str.
+  template<typename T> bool get(const std::string &str, T& value) const;
+  /** Returns a copy of the value of the variable with name str.
      Type are checked in Debug Mode.
      If the variable str doesn't exist return false else true.
      The data is removed after the call. */
@@ -39,10 +60,12 @@ struct TLP_SIMPLE_SCOPE DataSet {
   template<typename T> void set(const std::string &str,const T& value);
   /** return true if str exists else false.*/
   bool exist(const std::string &str) const;
-  /**Return an iterator on all values*/
-  Iterator< std::pair<std::string,DataType> > *getValues() const;
+  /** remove a named pair */
+  void remove(const std::string &str);
+  /** Return an iterator on all values */
+  Iterator< std::pair<std::string, DataType*> > *getValues() const;
 private:
-  std::map<std::string,DataType> data;
+  std::list< std::pair<std::string, DataType*> > data;
 };
 
 
@@ -52,25 +75,33 @@ struct TLP_SIMPLE_SCOPE StructDef {
   ///Add the variable of type T and name str in the structure.
   template<typename T> void add(const char* str,
 				const char* inHelp = 0,
-				const char* inDefValue = 0);
+				const char* inDefValue = 0,
+				bool mandatory = true);
+
+  ///Returns if a name field exists
+  bool hasField(std::string);
 
   ///Get iterator on structure fields
   Iterator< std::pair<std::string,std::string> >* getField() const;
 
   ///Get field help & default string-value (see also XXXType in Types.h)
-  std::string									  getHelp( std::string str ) const;
-  std::string									  getDefValue( std::string str ) const;
+  std::string getHelp( std::string str ) const;
+  std::string getDefValue( std::string str ) const;
+  void setDefValue(std::string name, std::string value);
+  ///Return if field is mandatory
+  bool isMandatory(std::string str) const;
 
   ///Remove the variable which have str has name in the structure.
   void		erase(std::string str);
 
   ///Build a default dataSet according to fields
-  ///The optional SuperGraph is needed to create properties (PProxy*)
-  void		buildDefaultDataSet( DataSet & ioDataSet, SuperGraph * inG = 0 );
+  ///The optional Graph is needed to create properties (PropertyInterface*)
+  void		buildDefaultDataSet( DataSet & ioDataSet, Graph * inG = 0 );
 private:
-  std::map<std::string,std::string> data;
+  std::list< std::pair<std::string, std::string> > data;
   std::map<std::string,std::string> help;
   std::map<std::string,std::string> defValue;
+  std::map<std::string,bool> mandatory;
 };
 
 
@@ -80,7 +111,7 @@ private:
 // Standard structDef's HTML Help
 
 #define	HTML_HELP_OPEN()	"<table><tr><td>" \
-							"<table CELLSPACING=1 bgcolor=\"#EEEEEE\">"
+							"<table CELLSPACING=5 bgcolor=\"#EEEEEE\">"
 #define	HTML_HELP_DEF(A,B)	"<tr><td><b>" A "</b></td><td><FONT COLOR=\"red\">" B "</td></tr>"
 #define	HTML_HELP_BODY()	"</table></td><td>"
 #define	HTML_HELP_CLOSE()	"</td></tr></table>"
@@ -92,9 +123,9 @@ private:
   	const char * paramHelp[] = {
 		// property
 		HTML_HELP_OPEN() \
-		HTML_HELP_DEF( "type", "MetricProxy" ) \
+		HTML_HELP_DEF( "type", "DoubleProperty" ) \
 		HTML_HELP_BODY() \
-		"This metricProxy is used to affect scalar values to superGraph items." \
+		"This metricProxy is used to affect scalar values to graph items." \
 		"The meaning of theses values depends of the choosen color model." \
 		HTML_HELP_CLOSE(),
 
@@ -110,13 +141,13 @@ private:
 	};
 	
 	...	
-	addParameter<MetricProxy>("property",paramHelp[0]);
+	addParameter<DoubleProperty>("property",paramHelp[0]);
     addParameter<int>("colormodel",paramHelp[1]);
 	...
 
  *
  */
-
+}
 
 #include "cxx/Reflect.cxx"
 
