@@ -1,8 +1,21 @@
 //-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 
+#ifndef DOXYGEN_NOTFOR_DEVEL
 #ifndef _SIMPLE_VECTOR_H_
 #define _SIMPLE_VECTOR_H_
 
+namespace tlp {
+
 // SimpleVector
 //   simple copy constructor
 //   deallocate with hand
@@ -71,4 +84,6 @@ class SimpleVector {
   }
 };
 
+}
 #endif
+#endif //DOXYGEN_NOTFOR_DEVEL
