@@ -1,9 +1,22 @@
 //-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 #ifndef TULIP_SIZE_H
 #define TULIP_SIZE_H
 #include <tulip/Vector.h>
 ///
-class Size : public tlp::Vector<float,3> {
+
+namespace tlp {
+
+class TLP_SCOPE Size : public tlp::Vector<float,3> {
 public:
   inline Size(const float width=0,const float height=0,const float depth=0);
   inline Size(const tlp::Vector<float,3> &);
@@ -42,4 +55,5 @@ void Size::setW(const float width) {array[0]=width;}
 void Size::setH(const float height) {array[1]=height;}
 void Size::setD(const float depth) {array[2]=depth;}
 
+}
 #endif
