@@ -1,8 +1,9 @@
 //-*-c++-*-
-/*
- Author: David Auber
- Email : auber@labri.fr
- Last modification : 10/12/2002
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by  
  the Free Software Foundation; either version 2 of the License, or     
@@ -14,6 +15,8 @@
 #include <tulip/tulipconf.h>
 #include <vector>
 
+namespace tlp {
+
 ///Interface of StableIterator,
 template<class itType> struct TLP_SCOPE StableIterator : public Iterator<itType> {
   StableIterator(Iterator<itType> *itIn) {
@@ -35,7 +38,7 @@ template<class itType> struct TLP_SCOPE StableIterator : public Iterator<itType>
   protected :
   std::vector<itType> cloneIt;
   typename std::vector<itType>::iterator itStl;
-  itType element;
 };
 
+}
 #endif
