@@ -1,3 +1,14 @@
+//-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 #ifndef STRINGCOLLECTION_H
 #define STRINGCOLLECTION_H
 
@@ -9,6 +20,8 @@
 
 #include "tulipconf.h"
 
+namespace tlp {
+
 struct TLP_SCOPE StringCollection : public std::vector<std::string> {
 
 private:
@@ -26,4 +39,5 @@ public:
   int         getCurrent();
 };
 
+}
 #endif
