@@ -1,8 +1,9 @@
 //-*-c++-*-
-/*
- Author: David Auber
- Email : auber@labri.fr
- Last modification : 01/09/2003
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by  
  the Free Software Foundation; either version 2 of the License, or     
@@ -23,27 +24,30 @@
 #endif
 #include "tulip/ObservableGraph.h"
 
-class SuperGraph;
-class SelectionProxy;
+namespace tlp {
+
+class Graph;
 
 /** \addtogroup graph_test */ 
 /*@{*/
 /// class for testing if a graph is triconnected
 class TLP_SCOPE TriconnectedTest : private GraphObserver {
 public:
-  static bool isTriconnected(SuperGraph *graph);
+  static bool isTriconnected(Graph *graph);
 
 private:
-  bool compute(SuperGraph *);
-  void addEdge(SuperGraph *,const edge);
-  void delEdge(SuperGraph *,const edge);
-  void reverseEdge(SuperGraph *,const edge);
-  void addNode(SuperGraph *,const node);
-  void delNode(SuperGraph *,const node);
-  void destroy(SuperGraph *);
+  bool compute(Graph *);
+  void addEdge(Graph *,const edge);
+  void delEdge(Graph *,const edge);
+  void reverseEdge(Graph *,const edge);
+  void addNode(Graph *,const node);
+  void delNode(Graph *,const node);
+  void destroy(Graph *);
   TriconnectedTest();
   static TriconnectedTest * instance;
   stdext::hash_map<unsigned long,bool> resultsBuffer;
 };
 /*@}*/
+
+}
 #endif
