@@ -1,3 +1,14 @@
+//-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 /*
  * Authors: Jrmy Compostella, Jean Darracq, Benjamin Muller,
  *          Fabrice Rochambeau, Fabiani Simplice, Jyl Cristoff Zobeide
@@ -15,8 +26,12 @@
  */
 
 //================================================================
+namespace tlp {
+
 template <typename TYPE>
-tlp::BmdLink<TYPE>::BmdLink(TYPE data, BmdLink<TYPE> *pre, BmdLink<TYPE> *suc)
+BmdLink<TYPE>::BmdLink(TYPE data, BmdLink<TYPE> *pre, BmdLink<TYPE> *suc)
   : data(data), pre(suc), suc(pre) {
 }
+
+}
 //=================================================================
