@@ -1,3 +1,14 @@
+//-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 #ifndef TULIPCONF_H
 #define TULIPCONF_H
 
@@ -10,7 +21,7 @@
 #    define stdext __gnu_cxx
 #  if  (__GNUC_MINOR__ < 4 && __GNUC__ < 4)
 #    include <ext/stl_hash_fun.h>
-#  else
+#  elif (__GNUC_MINOR__ < 3)
 #    include <ext/hash_fun.h>
 #  endif
 #endif
@@ -78,4 +89,15 @@
 #define TLP_QT_SIMPLE_SCOPE           
 #endif
 
+#ifdef _WIN32
+# 	ifdef DLL_TULIP_PLUGINSMANAGER
+#		define TLP_PLUGINSMANAGER_SCOPE         __declspec(dllexport)
+# 	else
+#		define TLP_PLUGINSMANAGER_SCOPE       __declspec(dllimport)
+# 	endif
+#endif
+#ifndef TLP_PLUGINSMANAGER_SCOPE
+#define TLP_PLUGINSMANAGER_SCOPE           
+#endif
+
 #endif //TULIPCONF_H
