@@ -1,3 +1,14 @@
+//-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 #include <algorithm>
 #include "tulip/RectangleArea.h"
 #include "tulip/Border.h"
@@ -9,20 +20,20 @@ const int BORDEREDGLYPH[] ={100, 101};
 const int BORDEREDGLYPHSIZE = sizeof(BORDEREDGLYPH) / sizeof(int);
 
 //====================================================================
-float evaluateBorderSize(int nodeLevel) {
+float tlp::evaluateBorderSize(int nodeLevel) {
     return BORDERWIDTH_ROOT * pow(BORDERWIDTH_LEVEL_FACTOR, nodeLevel);
 }
 
 //====================================================================
-float evaluateBorderSize(int nodeLevel, const RectangleArea& NodeArea, int) {
+float tlp::evaluateBorderSize(int nodeLevel, const RectangleArea& NodeArea, int) {
     float limitSize  = min(NodeArea.getWidth()  / BORDERWIDTH_LIMIT,
                            NodeArea.getHeight() / BORDERWIDTH_LIMIT);
-    float borderSize = evaluateBorderSize(nodeLevel);
+    float borderSize = tlp::evaluateBorderSize(nodeLevel);
     return min(limitSize, borderSize);
 }
 
 //====================================================================
-bool isBorderedGlyph(int glyph) {
+bool tlp::isBorderedGlyph(int glyph) {
     return binary_search(BORDEREDGLYPH, BORDEREDGLYPH + BORDEREDGLYPHSIZE,
                          glyph);
 }
