@@ -1,5 +1,17 @@
+//-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 #include <float.h>
 #include <tulip/Delaunay.h>
+#include <iostream>
 // Triangle from Jonathan Richard Shewchuk
 // is no longer used by Tulip
 //#define ANSI_DECLARATORS //ansi style declarations for triangle.h
@@ -13,7 +25,7 @@
 
 
 using namespace std;
-
+using namespace tlp;
 // Triangle from Jonathan Richard Shewchuk
 // is no longer used by Tulip
 //using namespace triangle_1_5;
@@ -549,11 +561,13 @@ void runTriangle (const vector<Coord> &points,
 //==============================================================
 void tlp::delaunayTriangulation (const vector<Coord> &points, 
 	    vector<pair<unsigned int, unsigned int> > &edges) {
+  std::cerr << __PRETTY_FUNCTION__ << " not yet implemented" << std::endl;
   //runTriangle (points, &edges);
 }//end delaunayTriangulation
 //==============================================================
 void tlp::delaunayTriangulation (const vector<Coord> &points, 
 	    vector< tlp::Array<unsigned int, 3> > &triangles) {
+  std::cerr << __PRETTY_FUNCTION__ << " not yet implemented" << std::endl;
   //runTriangle (points, NULL, &triangles);
 }//end delaunayTriangulation
 //==============================================================
@@ -566,5 +580,6 @@ void tlp::delaunayTriangulation (const vector<Coord> &points,
 void tlp::voronoiDiagram (const vector<Coord> &points,
 			  VoronoiDiagram &voronoiDiagram,
 			  bool returnVoronoiEdgeList) {
+  std::cerr << __PRETTY_FUNCTION__ << " not yet implemented" << std::endl;
   //runTriangle (points, NULL, NULL, returnVoronoiEdgeList, &voronoiDiagram);
 }//end voronoiDiagram
