@@ -1,16 +1,81 @@
 //-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
 #include <cassert>
 #include "tulip/GraphIterator.h"
-#include "tulip/SelectionProxy.h"
+#include "tulip/BooleanProperty.h"
+
+namespace tlp {
+
+#ifndef NDEBUG
+static int NumIterators = 0;
+
+void incrNumIterators() {
+  NumIterators++;
+}
+
+void decrNumIterators() {
+  NumIterators--;
+}
+
+void NodeIteratorObserver::addNode(Graph* g, node n) {
+  if (hasNext())
+    std::cerr << "Warning: node added while iterating !!!" << std::endl;
+}
+
+void NodeIteratorObserver::delNode(Graph* g, node n) {
+  if (hasNext())
+    std::cerr << "Warning: node deleted while iterating !!!" << std::endl;
+}
+   
+void EdgeIteratorObserver::addEdge(Graph* g, edge e) {
+  if (hasNext())
+    std::cerr << "Warning: edge added while iterating !!!" << std::endl;
+}
+
+void EdgeIteratorObserver::delEdge(Graph* g, edge e) {
+  if (hasNext())
+    std::cerr << "Warning: edge deleted while iterating !!!" << std::endl;
+}
+
+int getNumIterators() {
+  return NumIterators;
+}
+
+#else
+
+void incrNumIterators() {
+}
+
+void decrNumIterators() {
+}
+
+int getNumIterators() {
+  return 0;
+}
+
+#endif
+
 
 //============================================================
-SGraphNodeIterator::SGraphNodeIterator(const SuperGraph *sG, const MutableContainer<bool>& filter):FactorIterator<node>(sG,filter) {
+SGraphNodeIterator::SGraphNodeIterator(const Graph *sG, const MutableContainer<bool>& filter):FactorNodeIterator(sG,filter) {
   it=_parentGraph->getNodes();
   _hasnext=false;
+#ifndef NDEBUG
+  _parentGraph->addGraphObserver(this);
+#endif
   if (it->hasNext()) {
     curNode=it->next();
     while (_filter.get(curNode.id)!=true) {
@@ -21,6 +86,9 @@ SGraphNodeIterator::SGraphNodeIterator(const SuperGraph *sG, const MutableContai
   }
 }
 SGraphNodeIterator::~SGraphNodeIterator() {
+#ifndef NDEBUG
+  _parentGraph->removeGraphObserver(this);
+#endif
   delete it;
 }
 node SGraphNodeIterator::next() {
@@ -40,19 +108,23 @@ bool SGraphNodeIterator::hasNext(){
   return (_hasnext);
 }
 //===================================================================
-OutNodesIterator::OutNodesIterator(const SuperGraph *sG, const MutableContainer<bool>& filter,node n):FactorIterator<node>(sG,filter) {
+OutNodesIterator::OutNodesIterator(const Graph *sG, const MutableContainer<bool>& filter,node n):FactorNodeIterator(sG,filter) {
   it = new OutEdgesIterator(sG,filter,n);
 #ifndef NDEBUG
-  graph = sG;
+  sg = sG;
+  _parentGraph->addGraphObserver(this);
 #endif
 }
 OutNodesIterator::~OutNodesIterator() {
+#ifndef NDEBUG
+  _parentGraph->removeGraphObserver(this);
+#endif
   delete it;
 }
 node OutNodesIterator::next() {
 #ifndef NDEBUG
   node tmp = _parentGraph->target(it->next());
-  assert(graph->isElement(tmp));
+  assert(sg->isElement(tmp));
   return tmp;
 #endif
   return _parentGraph->target(it->next());
@@ -61,19 +133,23 @@ bool OutNodesIterator::hasNext() {
   return (it->hasNext());
 }
 //===================================================================
-InNodesIterator::InNodesIterator(const SuperGraph *sG, const MutableContainer<bool>& filter, node n):FactorIterator<node>(sG,filter),
+InNodesIterator::InNodesIterator(const Graph *sG, const MutableContainer<bool>& filter, node n):FactorNodeIterator(sG,filter),
 										   it(new InEdgesIterator(sG,filter,n)) {
 #ifndef NDEBUG
-  graph = sG;
+  sg = sG;
+  _parentGraph->addGraphObserver(this);
 #endif
 }
 InNodesIterator::~InNodesIterator() { 
+#ifndef NDEBUG
+  _parentGraph->removeGraphObserver(this);
+#endif
   delete it; 
 }
 node InNodesIterator:: next() {
 #ifndef NDEBUG
   node tmp = _parentGraph->source(it->next());
-  assert(graph->isElement(tmp));
+  assert(sg->isElement(tmp));
   return tmp;
 #endif
   return _parentGraph->source(it->next());
@@ -82,20 +158,24 @@ bool InNodesIterator::hasNext() {
   return (it->hasNext());
 }
 //===================================================================
-InOutNodesIterator::InOutNodesIterator(const SuperGraph *sG, const MutableContainer<bool>& filter,node n):FactorIterator<node>(sG,filter),
+InOutNodesIterator::InOutNodesIterator(const Graph *sG, const MutableContainer<bool>& filter,node n):FactorNodeIterator(sG,filter),
 											 it(new InOutEdgesIterator(sG,filter,n)),
 											 n(n) {
 #ifndef NDEBUG
-  graph = sG;
+  sg = sG;
+  _parentGraph->addGraphObserver(this);
 #endif
 }
 InOutNodesIterator::~InOutNodesIterator() {
+#ifndef NDEBUG
+  _parentGraph->removeGraphObserver(this);
+#endif
   delete it;
 }
 node InOutNodesIterator::next() {
 #ifndef NDEBUG
   node tmp = _parentGraph->opposite(it->next(),n);
-  assert(graph->isElement(tmp));
+  assert(sg->isElement(tmp));
   return tmp;
 #else
   return _parentGraph->opposite(it->next(),n);
@@ -105,9 +185,12 @@ bool InOutNodesIterator::hasNext() {
   return (it->hasNext());
 }
 //===============================================================
-SGraphEdgeIterator::SGraphEdgeIterator(const SuperGraph *sG, const MutableContainer<bool>& filter):FactorIterator<edge>(sG,filter) {
+SGraphEdgeIterator::SGraphEdgeIterator(const Graph *sG, const MutableContainer<bool>& filter):FactorEdgeIterator(sG,filter) {
   it=_parentGraph->getEdges();
   _hasnext=false;
+#ifndef NDEBUG
+  _parentGraph->addGraphObserver(this);
+#endif
   if (it->hasNext()) {
     curEdge=it->next();
     while (_filter.get(curEdge.id)!=true) {
@@ -118,6 +201,9 @@ SGraphEdgeIterator::SGraphEdgeIterator(const SuperGraph *sG, const MutableContai
   }
 }
 SGraphEdgeIterator::~SGraphEdgeIterator() {
+#ifndef NDEBUG
+  _parentGraph->removeGraphObserver(this);
+#endif
   delete it;
 }
 edge SGraphEdgeIterator::next() {
@@ -137,10 +223,13 @@ bool SGraphEdgeIterator::hasNext() {
   return (_hasnext);
 }
 //===================================================================
-OutEdgesIterator::OutEdgesIterator(const SuperGraph *sG, const MutableContainer<bool>& filter,node n):FactorIterator<edge>(sG,filter) {
+OutEdgesIterator::OutEdgesIterator(const Graph *sG, const MutableContainer<bool>& filter,node n):FactorEdgeIterator(sG,filter) {
   assert(sG->isElement(n));
   it=_parentGraph->getOutEdges(n);
   _hasnext=false;
+#ifndef NDEBUG
+  _parentGraph->addGraphObserver(this);
+#endif
   if (it->hasNext()){
     curEdge=it->next();
     while (_filter.get(curEdge.id)!=true) {
@@ -151,6 +240,9 @@ OutEdgesIterator::OutEdgesIterator(const SuperGraph *sG, const MutableContainer<
   }
 }
 OutEdgesIterator::~OutEdgesIterator() {
+#ifndef NDEBUG
+  _parentGraph->removeGraphObserver(this);
+#endif
   delete it;
 }
 edge OutEdgesIterator::next() {
@@ -171,10 +263,13 @@ bool OutEdgesIterator::hasNext() {
   return (_hasnext);
 }
 //===================================================================
-InEdgesIterator::InEdgesIterator(const SuperGraph *sG, const MutableContainer<bool>& filter, node n):FactorIterator<edge>(sG,filter){
+InEdgesIterator::InEdgesIterator(const Graph *sG, const MutableContainer<bool>& filter, node n):FactorEdgeIterator(sG,filter){
   assert(sG->isElement(n));
   it=_parentGraph->getInEdges(n);
   _hasnext=false;
+#ifndef NDEBUG
+  _parentGraph->addGraphObserver(this);
+#endif
   if (it->hasNext()){
     curEdge=it->next();
     while (_filter.get(curEdge.id)!=true){
@@ -185,6 +280,9 @@ InEdgesIterator::InEdgesIterator(const SuperGraph *sG, const MutableContainer<bo
   }
 }
 InEdgesIterator::~InEdgesIterator() {
+#ifndef NDEBUG
+  _parentGraph->removeGraphObserver(this);
+#endif
   delete it;
 }
 edge InEdgesIterator::next() {
@@ -204,10 +302,13 @@ bool InEdgesIterator::hasNext() {
   return (_hasnext);
 }
 //===================================================================
-InOutEdgesIterator::InOutEdgesIterator(const SuperGraph *sG,const MutableContainer<bool>& filter, node n):FactorIterator<edge>(sG,filter){
+InOutEdgesIterator::InOutEdgesIterator(const Graph *sG,const MutableContainer<bool>& filter, node n):FactorEdgeIterator(sG,filter){
   assert(sG->isElement(n));
   it=_parentGraph->getInOutEdges(n);
   _hasnext=false;
+#ifndef NDEBUG
+  _parentGraph->addGraphObserver(this);
+#endif
   if (it->hasNext()) {
     curEdge=it->next();
     while (_filter.get(curEdge.id)!=true) {
@@ -218,6 +319,9 @@ InOutEdgesIterator::InOutEdgesIterator(const SuperGraph *sG,const MutableContain
   }
 }
 InOutEdgesIterator::~InOutEdgesIterator() {
+#ifndef NDEBUG
+  _parentGraph->removeGraphObserver(this);
+#endif
   delete it;
 }
 edge InOutEdgesIterator::next() {
@@ -240,10 +344,17 @@ bool InOutEdgesIterator::hasNext() {
 //************************************************************
 //************************************************************
 //============================================================
-xSGraphNodeIterator::xSGraphNodeIterator(const SuperGraph *sG):
-  itId(((SuperGraphImpl *)sG)->nodeIds.getUsedId()) {
+xSGraphNodeIterator::xSGraphNodeIterator(const Graph *sG):
+  itId(((GraphImpl *)sG)->nodeIds.getIds()) {
+#ifndef NDEBUG
+  spG = (GraphImpl *)sG;
+  spG->addGraphObserver(this);
+#endif
 }
 xSGraphNodeIterator::~xSGraphNodeIterator(){
+#ifndef NDEBUG
+  spG->removeGraphObserver(this);
+#endif
   delete itId;
 }
 node xSGraphNodeIterator::next() {
@@ -253,10 +364,16 @@ bool xSGraphNodeIterator::hasNext() {
   return (itId->hasNext());
 }
 //===================================================================
-xOutNodesIterator::xOutNodesIterator(const SuperGraph *sG,const node n):
-  it(new xOutEdgesIterator((SuperGraphImpl *)sG,n)), spG((SuperGraphImpl *)sG) {
+xOutNodesIterator::xOutNodesIterator(const Graph *sG,const node n):
+  it(new xOutEdgesIterator((GraphImpl *)sG,n)), spG((GraphImpl *)sG) {
+#ifndef NDEBUG
+  spG->addGraphObserver(this);
+#endif
 }
 xOutNodesIterator::~xOutNodesIterator() {
+#ifndef NDEBUG
+  spG->removeGraphObserver(this);
+#endif
   delete it;
 }
 node xOutNodesIterator::next() {
@@ -266,10 +383,16 @@ bool xOutNodesIterator::hasNext() {
   return (it->hasNext());
 }
 //===================================================================
-xInNodesIterator::xInNodesIterator(const SuperGraph *sG,const node n): 
-  it(new xInEdgesIterator(sG,n)), spG((SuperGraphImpl *)sG) {
+xInNodesIterator::xInNodesIterator(const Graph *sG,const node n): 
+  it(new xInEdgesIterator(sG,n)), spG((GraphImpl *)sG) {
+#ifndef NDEBUG
+  spG->addGraphObserver(this);
+#endif
 }
 xInNodesIterator::~xInNodesIterator() {
+#ifndef NDEBUG
+  spG->removeGraphObserver(this);
+#endif
   delete it;
 }
 node xInNodesIterator:: next() {
@@ -279,12 +402,19 @@ bool xInNodesIterator::hasNext() {
   return (it->hasNext());
 }
 //===================================================================
-xInOutNodesIterator::xInOutNodesIterator(const SuperGraph *sG,const node n):
-  it(((SuperGraphImpl *)sG)->nodes[n.id].begin()),
-  itEnd(((SuperGraphImpl *)sG)->nodes[n.id].end()),
-  n(n), spG((SuperGraphImpl *)sG) {
+xInOutNodesIterator::xInOutNodesIterator(const Graph *sG,const node n):
+  it(((GraphImpl *)sG)->nodes[n.id].begin()),
+  itEnd(((GraphImpl *)sG)->nodes[n.id].end()),
+  n(n), spG((GraphImpl *)sG) {
+#ifndef NDEBUG
+  spG->addGraphObserver(this);
+#endif
+}
+xInOutNodesIterator::~xInOutNodesIterator() {
+#ifndef NDEBUG
+  spG->removeGraphObserver(this);
+#endif
 }
-xInOutNodesIterator::~xInOutNodesIterator() {}
 node xInOutNodesIterator::next() {
   edge tmp=(*it);
   it++;
@@ -294,10 +424,17 @@ bool xInOutNodesIterator::hasNext() {
   return (it!=itEnd);
 }
 //===============================================================
-xSGraphEdgeIterator::xSGraphEdgeIterator(const SuperGraph *sG):
-  itId(((SuperGraphImpl *)sG)->edgeIds.getUsedId()) {
+xSGraphEdgeIterator::xSGraphEdgeIterator(const Graph *sG):
+  itId(((GraphImpl *)sG)->edgeIds.getIds()) {
+#ifndef NDEBUG
+  spG = (GraphImpl *)sG;
+  spG->addGraphObserver(this);
+#endif
 }
 xSGraphEdgeIterator::~xSGraphEdgeIterator(){
+#ifndef NDEBUG
+  spG->removeGraphObserver(this);
+#endif
   delete itId;
 }
 edge xSGraphEdgeIterator::next() {
@@ -307,10 +444,13 @@ bool xSGraphEdgeIterator::hasNext() {
   return itId->hasNext();
 }
 //===================================================================
-xOutEdgesIterator::xOutEdgesIterator(const SuperGraph *sG,const node n):
-  it(((SuperGraphImpl *)sG)->nodes[n.id].begin()),
-  itEnd(((SuperGraphImpl *)sG)->nodes[n.id].end()),
-  n(n), spG((SuperGraphImpl *)sG) {
+xOutEdgesIterator::xOutEdgesIterator(const Graph *sG,const node n):
+  it(((GraphImpl *)sG)->nodes[n.id].begin()),
+  itEnd(((GraphImpl *)sG)->nodes[n.id].end()),
+  n(n), spG((GraphImpl *)sG) {
+#ifndef NDEBUG
+  spG->addGraphObserver(this);
+#endif
   if (it!=itEnd) {
     curEdge=*it;
     while(1) {
@@ -336,6 +476,9 @@ xOutEdgesIterator::xOutEdgesIterator(const SuperGraph *sG,const node n):
   }
 }
 xOutEdgesIterator::~xOutEdgesIterator() {
+#ifndef NDEBUG
+  spG->removeGraphObserver(this);
+#endif
 }
 edge xOutEdgesIterator::next() {
   assert(hasNext());
@@ -370,10 +513,13 @@ bool xOutEdgesIterator::hasNext() {
   return (it!=itEnd);
 }
 //===================================================================
-xInEdgesIterator::xInEdgesIterator(const SuperGraph *sG,const node n):
-  it(((SuperGraphImpl *)sG)->nodes[n.id].begin()),
-  itEnd(((SuperGraphImpl *)sG)->nodes[n.id].end()),
-  n(n), spG((SuperGraphImpl *)sG) {
+xInEdgesIterator::xInEdgesIterator(const Graph *sG,const node n):
+  it(((GraphImpl *)sG)->nodes[n.id].begin()),
+  itEnd(((GraphImpl *)sG)->nodes[n.id].end()),
+  n(n), spG((GraphImpl *)sG) {
+#ifndef NDEBUG
+  spG->addGraphObserver(this);
+#endif
   if (it!=itEnd) {
     curEdge=*it;
     while(1) {
@@ -399,6 +545,9 @@ xInEdgesIterator::xInEdgesIterator(const SuperGraph *sG,const node n):
   }
 }
 xInEdgesIterator::~xInEdgesIterator() {
+#ifndef NDEBUG
+  spG->removeGraphObserver(this);
+#endif
 }
 edge xInEdgesIterator::next() {
   assert(hasNext());
@@ -433,11 +582,19 @@ bool xInEdgesIterator::hasNext() {
   return (it!=itEnd);
 }
 //===================================================================
-xInOutEdgesIterator::xInOutEdgesIterator(const SuperGraph *sG, const node n): 
-  it(((SuperGraphImpl *)sG)->nodes[n.id].begin()),
-  itEnd(((SuperGraphImpl *)sG)->nodes[n.id].end()){
+xInOutEdgesIterator::xInOutEdgesIterator(const Graph *sG, const node n): 
+  it(((GraphImpl *)sG)->nodes[n.id].begin()),
+  itEnd(((GraphImpl *)sG)->nodes[n.id].end()){
+#ifndef NDEBUG
+  spG = (GraphImpl *)sG;
+  spG->addGraphObserver(this);
+#endif
+}
+xInOutEdgesIterator::~xInOutEdgesIterator(){
+#ifndef NDEBUG
+  spG->removeGraphObserver(this);
+#endif
 }
-xInOutEdgesIterator::~xInOutEdgesIterator(){}
 edge xInOutEdgesIterator::next() {
   edge tmp=(*it);
   ++it;
@@ -447,12 +604,4 @@ bool xInOutEdgesIterator::hasNext() {
   return (it!=itEnd);
 }
 //===================================================================
-
-
-
-
-
-
-
-
-
+} // namespace tpl
