@@ -1,3 +1,14 @@
+//-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -5,8 +16,9 @@
 #include "tulip/MapIterator.h"
 
 using namespace std;
+using namespace tlp;
 
-edge tlp::nextFaceEdge(SuperGraph *g, edge e, node n) {
+edge tlp::nextFaceEdge(Graph *g, edge e, node n) {
   EdgeMapIterator it(g, e, n);
   edge result;
   if (it.hasNext())
@@ -14,7 +26,7 @@ edge tlp::nextFaceEdge(SuperGraph *g, edge e, node n) {
   return result;
 }
 
-NodeMapIterator::NodeMapIterator(SuperGraph *sg, node source, node target) {
+NodeMapIterator::NodeMapIterator(Graph *sg, node source, node target) {
   assert(cloneIt.empty());
   bool start=true;
   Iterator<node> *itIn=sg->getInOutNodes(target);
@@ -48,7 +60,7 @@ bool NodeMapIterator::hasNext() {
 
 //=========================================
 
-EdgeMapIterator::EdgeMapIterator(SuperGraph *sg, edge source, node target) {
+EdgeMapIterator::EdgeMapIterator(Graph *sg, edge source, node target) {
   adj.resize(sg->deg(target));
   finished = false;
   treat =0;
