@@ -1,9 +1,22 @@
+//-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 #include <cassert>
 #include <iostream>
 #include "tulip/Observable.h"
 
 
 using namespace std;
+using namespace stdext;
+using namespace tlp;
 
 #ifdef _WIN32 
 #ifdef DLL_EXPORT
@@ -20,29 +33,44 @@ static bool unholdLock=false;
 //===============================================================
 void Observable::notifyDestroy() {
   //  cerr << "Observable::notifyObservers" << endl;
-  std::list<Observer*> tmpList(observersList);
-  list<Observer*>::iterator itlObs;
-  for (itlObs=tmpList.begin(); itlObs!=tmpList.end(); ++itlObs)
-    (*itlObs)->observableDestroyed(this);
+  slist<Observer*>::iterator itlObs = observersList.begin();
+  slist<Observer*>::iterator itle = observersList.end();
+  while (itlObs != itle) {
+    Observer* observer = *itlObs;
+    // iterator is incremented before
+    // to ensure it will not be invalidated
+    // during the call to the observableDestroyed method
+    ++itlObs;
+    observer->observableDestroyed(this);
+  }
 }
 //===============================================================
 void Observable::notifyObservers() {
+  slist<Observer*>::iterator itlObs = observersList.begin();
+  slist<Observer*>::iterator itle = observersList.end();
+  if (itlObs == itle)
+    return;
+
   if (unholdLock) {
     cerr << "Cannot notifyObservers during unholdings" << endl;
     return;
   }
   //  cerr << "Observable::notifyObservers" << endl;
-  list<Observer*>::iterator itlObs;
   assert(holdCounter>=0);
   if (holdCounter)
-    for (itlObs=observersList.begin();itlObs!=observersList.end();++itlObs)
+    for (;itlObs != itle; ++itlObs)
       holdMap[*itlObs].insert(this);
   else {
     set<Observable *> tmpSet;
-    std::list<Observer*> tmpList(observersList);
     tmpSet.insert(this);
-    for (itlObs=tmpList.begin();itlObs!=tmpList.end();++itlObs)
-      (*itlObs)->update(tmpSet.begin(),tmpSet.end());
+    while(itlObs != itle) {
+      Observer* observer = *itlObs;
+      // iterator is incremented before
+      // to ensure it will not be invalidated
+      // during the call to the update method
+      ++itlObs;
+      observer->update(tmpSet.begin(),tmpSet.end());
+    }
   }
 }
 //===============================================================
