@@ -1,3 +1,14 @@
+//-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 /**
  Author: David Auber
  Email : auber@labri.fr
@@ -12,18 +23,19 @@
 #endif
 
 #include "tulip/PropertyManager.h"
-#include "tulip/SuperGraph.h"
-#include "tulip/PropertyProxy.h"
+#include "tulip/Graph.h"
+#include "tulip/AbstractProperty.h"
 
 using namespace std;
+using namespace tlp;
 
 //==============================================================
-PropertyManagerImpl::PropertyManagerImpl(SuperGraph *spGr) {
-  superGraph=spGr;
+PropertyManagerImpl::PropertyManagerImpl(Graph *spGr) {
+  graph=spGr;
 }
 //==============================================================
 PropertyManagerImpl::~PropertyManagerImpl() {
-  map<string,PProxy*>::iterator itP;
+  map<string,PropertyInterface*>::iterator itP;
   for (itP=propertyProxyMap.begin();itP!=propertyProxyMap.end();++itP) {
     delete (*itP).second;
   }
@@ -33,10 +45,11 @@ bool PropertyManagerImpl::existProperty(const string &str) {
   if (existLocalProperty(str)) 
     return true;
   else {
-    if (superGraph->getFather()==superGraph)
-        return false;
+    Graph* super = graph->getSuperGraph();
+    if (super == graph)
+      return false;
     else 
-      return (superGraph->getFather()->existProperty(str));
+      return (super->existProperty(str));
   }
 }
 //==============================================================
@@ -44,37 +57,39 @@ bool PropertyManagerImpl::existLocalProperty(const string &str) {
   return (propertyProxyMap.find(str)!=propertyProxyMap.end());
 }
 //==============================================================
-void PropertyManagerImpl::setLocalProxy(const string &str, PProxy *p) {
+void PropertyManagerImpl::setLocalProxy(const string &str, PropertyInterface *p) {
   if (existLocalProperty(str))
     delete propertyProxyMap[str];
   propertyProxyMap[str]=p;
 }
 //==============================================================
-PProxy* PropertyManagerImpl::getProperty(const string &str) {
+PropertyInterface* PropertyManagerImpl::getProperty(const string &str) {
   assert(existProperty(str));
   //  cerr << "Get Proxy :" << str << endl;
   if (existLocalProperty(str))
     return this->getLocalProperty(str);
   else {
-      return (superGraph->getFather()->getProperty(str));
-    }
-  return 0;
+    Graph* super = graph->getSuperGraph();
+    if (super != graph)
+      return (super->getProperty(str));
+  }
+  return NULL;
 }
 //==============================================================
-PProxy* PropertyManagerImpl::getLocalProperty(const string &str) {
+PropertyInterface* PropertyManagerImpl::getLocalProperty(const string &str) {
   assert(existLocalProperty(str));
   return (propertyProxyMap[str]);
 }
 //==============================================================
-void PropertyManagerImpl::delLocalProperty(const string &str) {
-  PProxy *tmpM;
-  map<string,PProxy *>::iterator it;
+PropertyInterface* PropertyManagerImpl::delLocalProperty(const string &str) {
+  map<string,PropertyInterface *>::iterator it;
   it=propertyProxyMap.find(str);
   if (it!=propertyProxyMap.end()) {
-    tmpM=(*it).second;
+    PropertyInterface* prop = (*it).second;
     propertyProxyMap.erase(it);
-    delete tmpM;
+    return prop;
   }
+  return NULL;
 }
 Iterator<string>*  PropertyManagerImpl::getLocalProperties() {
   return (new LocalPropertiesIterator(this));
@@ -99,9 +114,9 @@ bool LocalPropertiesIterator::hasNext() {
 //===============================================================
 InheritedPropertiesIterator::InheritedPropertiesIterator(PropertyManager *ppc) {
   this->ppc=ppc; 
-  if (ppc->superGraph->getFather()!=ppc->superGraph) {
+  if (ppc->graph->getSuperGraph()!=ppc->graph) {
     //Rcupration des proprites locale du pre.
-    Iterator<string> *itS=ppc->superGraph->getFather()->getLocalProperties();
+    Iterator<string> *itS=ppc->graph->getSuperGraph()->getLocalProperties();
     for (;itS->hasNext();) {
       string tmp=itS->next();
       if (!ppc->existLocalProperty(tmp)) {
@@ -109,7 +124,7 @@ InheritedPropertiesIterator::InheritedPropertiesIterator(PropertyManager *ppc) {
       }
     } delete itS;
     //Rcupration des proprites hrites du pre.
-    itS=ppc->superGraph->getFather()->getInheritedProperties();
+    itS=ppc->graph->getSuperGraph()->getInheritedProperties();
     for (;itS->hasNext();) {
       string tmp=itS->next();
       if (!ppc->existLocalProperty(tmp)) {
@@ -131,14 +146,14 @@ bool InheritedPropertiesIterator::hasNext() {
 }
 //===============================================================
 void PropertyManagerImpl::erase(const node n) {
-  map<string,PProxy*>::iterator itP;
+  map<string,PropertyInterface*>::iterator itP;
   for (itP=propertyProxyMap.begin();itP!=propertyProxyMap.end();++itP) {
     itP->second->erase(n);
   }
 }
 //===============================================================
 void PropertyManagerImpl::erase(const edge e) {
-  map<string,PProxy*>::iterator itP;
+  map<string,PropertyInterface*>::iterator itP;
   for (itP=propertyProxyMap.begin();itP!=propertyProxyMap.end();++itP) {
     itP->second->erase(e);
   }
