@@ -1,10 +1,21 @@
 //-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 
 #include "tulip/Types.h"
-#include "tulip/SuperGraph.h"
+#include "tulip/Graph.h"
 #include "tulip/StringCollection.h"
 
 using namespace std;
+using namespace tlp;
 
 namespace {
   int nocase_cmp(const string & s1, const string& s2) {
@@ -41,20 +52,20 @@ namespace {
 }
 
 //
-// MetaGraphType
+// GraphType
 
-MetaGraphType::RealType MetaGraphType::undefineValue() {
+GraphType::RealType GraphType::undefinedValue() {
   return 0;
 }
 
-MetaGraphType::RealType MetaGraphType::defaultValue() {
-	return 0;
+GraphType::RealType GraphType::defaultValue() {
+  return 0;
 }
 
-void MetaGraphType::del(MetaGraphType::RealType element) {
+void GraphType::del(GraphType::RealType element) {
 }
 
-string MetaGraphType::toString( const RealType & v ) {
+string GraphType::toString( const RealType & v ) {
   // NULL ?
   if( !v )
     return string();
@@ -63,16 +74,70 @@ string MetaGraphType::toString( const RealType & v ) {
   return oss.str();
 }
 
-bool MetaGraphType::fromString( RealType & v, const string & s ) {
-  v = 0;
-  return false;
+bool GraphType::fromString(RealType & v, const string & s ) {
+  istringstream iss;
+  iss.str( s );
+  unsigned long lv;
+  bool ok = iss >> lv;
+  if (ok)
+    v = (RealType) lv;
+  else
+    v = 0;
+  return ok;
 }
 
+//
+// EdgeSetType
+
+set<edge> EdgeSetType::undefinedValue() {
+  return set<edge>();
+}
+
+set<edge> EdgeSetType::defaultValue() {
+  return set<edge>();
+}
+
+void EdgeSetType::del(EdgeSetType::RealType &element) {
+  element.clear();
+}
+
+string EdgeSetType::toString( const RealType & v ) {
+  ostringstream oss;
+  oss << '(';
+  set<edge>::const_iterator it;
+  for(it = v.begin() ; it != v.end() ; ++it)
+    oss << (*it).id;
+  oss << ')';
+  return oss.str();
+}
+
+bool EdgeSetType::fromString( RealType & v, const string & s ) {
+  v.clear();
+  // for compatibility with older version (3.0)
+  if (s.empty())
+    return true;
+  istringstream iss;
+  iss.str( s );
+  char c;
+  if( !(iss >> c) || c!='(' )
+    return false;
+  edge e;
+  for( ;; ) {
+    if( !(iss >> c) )
+      return false;
+    if( c == ')' )
+      return true;
+    iss.unget();
+    if( !(iss >> e.id) )
+      return false;
+    v.insert( e );
+  }
+}
 
 //
 // DoubleType
 
-double DoubleType::undefineValue() {
+double DoubleType::undefinedValue() {
   return DBL_MIN;
 }
 
@@ -96,25 +161,25 @@ bool DoubleType::fromString( RealType & v, const string & s ) {
 }
 
 //
-// IntType
-int IntType::undefineValue() {
-	return INT_MIN;
+// IntegerType
+int IntegerType::undefinedValue() {
+  return INT_MIN;
 }
 
-int IntType::defaultValue() {
+int IntegerType::defaultValue() {
   return 0;
 }
 
-void IntType::del(IntType::RealType element) {
+void IntegerType::del(IntegerType::RealType element) {
 }
 
-string IntType::toString( const RealType & v ) {
+string IntegerType::toString( const RealType & v ) {
   ostringstream oss;
   oss << v;
   return oss.str();
 }
 
-bool IntType::fromString( RealType & v, const string & s ) {
+bool IntegerType::fromString( RealType & v, const string & s ) {
   istringstream iss;
   iss.str( s );
   return (iss >> v);
@@ -125,7 +190,7 @@ bool IntType::fromString( RealType & v, const string & s ) {
 //
 // BooleanType
 
-bool BooleanType::undefineValue() {
+bool BooleanType::undefinedValue() {
   return false;
 }
 
@@ -154,18 +219,16 @@ bool BooleanType::fromString( RealType & v, const string & s ) {
 //
 // LineType
 
-vector<Coord> LineType::undefineValue() {
-  vector<Coord> tmp;
-  return tmp;
+vector<Coord> LineType::undefinedValue() {
+  return vector<Coord>();
 }
 
 vector<Coord> LineType::defaultValue() {
-  vector<Coord> tmpList;
-  return tmpList;
+  return vector<Coord>();
 }
 
 void LineType::del(LineType::RealType &element) {
-	element.clear();
+  element.clear();
 }
 
 string LineType::toString( const RealType & v ) {
@@ -201,7 +264,7 @@ bool LineType::fromString( RealType & v, const string & s ) {
 
 //
 // PointType
-Coord PointType::undefineValue() {
+Coord PointType::undefinedValue() {
   Coord tmp;
   tmp.set(DBL_MIN,DBL_MIN,DBL_MIN);
   return tmp;
@@ -209,9 +272,7 @@ Coord PointType::undefineValue() {
 
 Coord
 PointType::defaultValue() {
-  Coord tmp;
-  tmp.set(rand()%1024,rand()%1024,rand()%1024);
-  return tmp;
+  return Coord(rand()%1024,rand()%1024,rand()%1024);
 }
 
 void PointType::del(PointType::RealType element) {
@@ -232,7 +293,7 @@ bool PointType::fromString( RealType & v, const string & s ) {
 //
 // SizeType
 
-Size SizeType::undefineValue() {
+Size SizeType::undefinedValue() {
   return Size(DBL_MIN,DBL_MIN,DBL_MIN);
 }
 
@@ -258,7 +319,7 @@ bool SizeType::fromString( RealType & v, const string & s ) {
 //
 // StringType
 
-string StringType::undefineValue() {
+string StringType::undefinedValue() {
   return string("");
 }
 
@@ -281,12 +342,12 @@ bool StringType::fromString( RealType & v, const string & s ) {
 //
 // ColorType
 
-Color ColorType::undefineValue() {
+Color ColorType::undefinedValue() {
   return Color(255,255,255,255);
 }
 
 Color ColorType::defaultValue() {
-	return Color();
+  return Color();
 }
 
 void ColorType::del(ColorType::RealType element) {
@@ -307,7 +368,7 @@ bool ColorType::fromString( RealType & v, const string & s ) {
 //
 // StringCollectionType
 
-StringCollection StringCollectionType::undefineValue() {
+StringCollection StringCollectionType::undefinedValue() {
   return StringCollection();
 }
 
