@@ -1,4 +1,14 @@
 //-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 #ifndef _ConvolutionClustering_H
 #define _ConvolutionClustering_H
 
@@ -6,13 +16,11 @@
 
 #include <tulip/TulipPlugin.h>
 
-class MetricProxy;
-
-class ConvolutionClustering:public Clustering
+class ConvolutionClustering:public tlp::Algorithm
 { 
 public:
 
-  ConvolutionClustering(ClusterContext);
+  ConvolutionClustering(tlp::AlgorithmContext);
   ~ConvolutionClustering();
   bool run();
   bool check(std::string &);
@@ -27,7 +35,7 @@ private:
   std::vector<double> smoothHistogram;
   std::map<int,int> histogramOfValues;
   int histosize,threshold,width;
-  MetricProxy *metric;
+  tlp::DoubleProperty *metric;
 };
 
 #endif
