@@ -1,6 +1,18 @@
+//-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 #include <tulip/TulipPlugin.h>
 
 using namespace std;
+using namespace tlp;
 
 
 
@@ -24,7 +36,7 @@ namespace
 
 struct CompleteGraph:public ImportModule {
 
-  CompleteGraph(ClusterContext context):ImportModule(context) {
+  CompleteGraph(AlgorithmContext context):ImportModule(context) {
     addParameter<int>("nodes",paramHelp[0],"5");
   }
   ~CompleteGraph(){
@@ -36,24 +48,27 @@ struct CompleteGraph:public ImportModule {
       dataSet->get("nodes", nbNodes);
     }
     
+    if (pluginProgress)
+      pluginProgress->showPreview(false);
+
     for (int j=0; j<nbNodes; ++j) 
-      superGraph->addNode();
+      graph->addNode();
     Iterator<node> *it1,*it2;
-    it1=superGraph->getNodes();
+    it1=graph->getNodes();
     int i=0;
     while (it1->hasNext()) {
       if (pluginProgress->progress(i,nbNodes) != TLP_CONTINUE) 
 	return false;
       i++;
       node n1=it1->next();
-      it2=superGraph->getNodes();
+      it2=graph->getNodes();
       while (it2->hasNext()) {
 	node n2=it2->next();
-	if (n1!=n2) superGraph->addEdge(n1,n2);
+	if (n1!=n2) graph->addEdge(n1,n2);
       } delete it2;
     } delete it1;
     return true;
   }
 };
 
-IMPORTPLUGINOFGROUP(CompleteGraph,"Complete General Graph","Auber","16/12/2002","0","0","1","Graphs")
+IMPORTPLUGINOFGROUP(CompleteGraph,"Complete General Graph","Auber","16/12/2002","","1.0","Graphs")
