@@ -1,6 +1,18 @@
+//-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 #include <tulip/TulipPlugin.h>
 
 using namespace std;
+using namespace tlp;
 
 
 
@@ -31,7 +43,7 @@ namespace
 
 
 struct CompleteTree:public ImportModule {
-  CompleteTree(ClusterContext context):ImportModule(context) {
+  CompleteTree(AlgorithmContext context):ImportModule(context) {
     addParameter<int>("depth",paramHelp[0],"5");
     addParameter<int>("degree",paramHelp[1],"2");
   }
@@ -39,9 +51,9 @@ struct CompleteTree:public ImportModule {
   }
   void buildNode(node n,unsigned int degree,int depth) {
     if (depth<1) return;
-    for (int i=0;i<degree;++i) {
-      node n1=superGraph->addNode();
-      superGraph->addEdge(n,n1);
+    for (unsigned int i=0;i<degree;++i) {
+      node n1=graph->addNode();
+      graph->addEdge(n,n1);
       buildNode(n1,degree,depth - 1);
     }
   }
@@ -52,9 +64,9 @@ struct CompleteTree:public ImportModule {
       dataSet->get("depth", depth);
       dataSet->get("degree", degree);
     }
-    node n=superGraph->addNode();
+    node n=graph->addNode();
     buildNode(n,degree,depth);
     return true;
   }
 };
-IMPORTPLUGINOFGROUP(CompleteTree,"Complete Tree","Auber","08/09/2002","0","0","1","Graphs")
+IMPORTPLUGINOFGROUP(CompleteTree,"Complete Tree","Auber","08/09/2002","","1.0","Graphs")
