@@ -1,7 +1,18 @@
-#include <qfiledialog.h>
-#include <tulip/TulipPlugin.h>
+//-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 #include <sys/stat.h>
 #include <sys/types.h>
+#include <errno.h>
+#include <tulip/TulipPlugin.h>
 
 #ifdef _WIN32
 #include <windows.h>
@@ -10,15 +21,36 @@
 #endif
 
 using namespace std;
+using namespace tlp;
 
-struct FileSystem:public ImportModule {
-  FileSystem(ClusterContext context):ImportModule(context) {}
+namespace {
+  static const char * paramHelp[] = {
+    // directory
+    HTML_HELP_OPEN()				    \
+    HTML_HELP_DEF( "type", "directory pathname" )		    \
+    HTML_HELP_BODY()						      \
+    "This parameter indicates the directory to import."	      \
+    HTML_HELP_CLOSE(),
+  };
+}
+
+/** \addtogroup import */
+/*@{*/
+/// Import a tree representation of a file system directory.
+/** This plugin enables to capture in a tree the full hierarchy of
+ *  of a given file system directory
+ */
+class FileSystem:public ImportModule {
+public:
+  FileSystem(AlgorithmContext context):ImportModule(context) {
+    addParameter<string>("dir::directory", paramHelp[0]);
+  }
   ~FileSystem(){}
 
-  MetricProxy *size,*gid,*uid,*lastaccess,*lastmodif,*lastchange;
-  IntProxy *type;
-  StringProxy *label;
-  LayoutProxy *layout;
+  DoubleProperty *size,*gid,*uid,*lastaccess,*lastmodif,*lastchange;
+  IntegerProperty *type;
+  StringProperty *label;
+  LayoutProperty *layout;
   int progress;
 
 
@@ -37,25 +69,25 @@ struct FileSystem:public ImportModule {
     dirent *entry;
     #else
     HANDLE hFind; 
-  	WIN32_FIND_DATA FindData; 
-  	SetCurrentDirectory (directory.c_str()); 
-  	hFind=FindFirstFile ("*.*", &FindData); 
-  	bool endOfDirectory = (hFind == NULL) || (hFind == INVALID_HANDLE_VALUE);
-  	if(endOfDirectory) {
-    pluginProgress->stop();
-    return pluginProgress->state();
-  	}
+    WIN32_FIND_DATA FindData; 
+    SetCurrentDirectory (directory.c_str()); 
+    hFind=FindFirstFile ("*.*", &FindData); 
+    bool endOfDirectory = (hFind == NULL) || (hFind == INVALID_HANDLE_VALUE);
+    if (endOfDirectory) {
+      pluginProgress->stop();
+      return pluginProgress->state();
+    }
     #endif
     struct stat infoEntry;
     #ifdef _WIN32
      while (!endOfDirectory) {
-   	  if (!strcmp("..",FindData.cFileName) || !strcmp(".",FindData.cFileName)) {
-   	  	endOfDirectory = !(FindNextFile (hFind, &FindData));
-   	  	continue;
-   	  }
-      string entryName=FindData.cFileName;
-      string pathEntry=directory+entryName;
-	  stat(pathEntry.c_str(),&infoEntry);
+       if (!strcmp("..",FindData.cFileName) || !strcmp(".",FindData.cFileName)) {
+   	 endOfDirectory = !(FindNextFile (hFind, &FindData));
+   	 continue;
+       }
+       string entryName=FindData.cFileName;
+       string pathEntry=directory+entryName;
+       stat(pathEntry.c_str(),&infoEntry);
      #else
     while ((entry = readdir(dir))!=0) {
       if (!strcmp("..",entry->d_name) || !strcmp(".",entry->d_name)) continue;
@@ -64,8 +96,8 @@ struct FileSystem:public ImportModule {
       lstat(pathEntry.c_str(),&infoEntry);
     #endif
       if (infoEntry.st_dev==true) continue;
-      node newNode=superGraph->addNode();
-      superGraph->addEdge(n,newNode);
+      node newNode=graph->addNode();
+      graph->addEdge(n,newNode);
       label->setNodeValue(newNode,entryName);
       if (infoEntry.st_size<1)
 	size->setNodeValue(newNode,1);
@@ -80,11 +112,11 @@ struct FileSystem:public ImportModule {
       if ((infoEntry.st_mode & S_IFMT) == S_IFDIR) {
 	x += 2;
 	if (readDir(newNode,pathEntry+"/", x , x ) == TLP_CANCEL)
-	  superGraph->delNode(newNode);
+	  graph->delNode(newNode);
 	else {
 	  double newSize=0;
 	  Coord tmp(0,0,0);
-	  Iterator<node> *itN=superGraph->getOutNodes(newNode);
+	  Iterator<node> *itN=graph->getOutNodes(newNode);
 	  for (;itN->hasNext();) {
 	    node itn=itN->next();
 	    newSize+=size->getNodeValue(itn);
@@ -92,11 +124,11 @@ struct FileSystem:public ImportModule {
 	  }
 	  delete itN;
 	  size->setNodeValue(newNode,newSize/1024.0);
-	  if (superGraph->outdeg(newNode) == 0) {
+	  if (graph->outdeg(newNode) == 0) {
 	    layout->setNodeValue(newNode, Coord(x, y, 0));
 	    x += 2;
 	  } else {
-	    tmp[0] /= superGraph->outdeg(newNode);
+	    tmp[0] /= graph->outdeg(newNode);
 	    tmp[1] = y;
 	    layout->setNodeValue(newNode, tmp);
 	  }
@@ -118,30 +150,37 @@ struct FileSystem:public ImportModule {
   }
 
   bool import(const string &name) {
-    bool ok;
-    size=superGraph->getProperty<MetricProxy>("size");
-    uid=superGraph->getProperty<MetricProxy>("uid");
-    gid=superGraph->getProperty<MetricProxy>("gid");
-    lastaccess=superGraph->getProperty<MetricProxy>("lastaccess");
-    lastmodif=superGraph->getProperty<MetricProxy>("lastmodif");
-    lastchange=superGraph->getProperty<MetricProxy>("lastchange");
-    type=superGraph->getProperty<IntProxy>("viewShape");
-    layout=superGraph->getProperty<LayoutProxy>("viewLayout");
-    label=superGraph->getProperty<StringProxy>("name");
+    size=graph->getProperty<DoubleProperty>("size");
+    uid=graph->getProperty<DoubleProperty>("uid");
+    gid=graph->getProperty<DoubleProperty>("gid");
+    lastaccess=graph->getProperty<DoubleProperty>("lastaccess");
+    lastmodif=graph->getProperty<DoubleProperty>("lastmodif");
+    lastchange=graph->getProperty<DoubleProperty>("lastchange");
+    type=graph->getProperty<IntegerProperty>("viewShape");
+    layout=graph->getProperty<LayoutProperty>("viewLayout");
+    label=graph->getProperty<StringProperty>("name");
     type->setAllNodeValue(0);
     layout->setAllNodeValue(Coord(0,0,0));
-    node newNode=superGraph->addNode();
-    QString dirName=QFileDialog::getExistingDirectory ();
-    if (dirName.isNull()) return false;
+    node newNode=graph->addNode();
+    string dirName;
+    if (!dataSet->get("dir::directory", dirName) || dirName.empty()) {
+      pluginProgress->setError("No directory");
+      return false;
+    }
 
     struct stat infoEntry;
+    int result;
     #ifdef _WIN32
-    stat(dirName.ascii(),&infoEntry);
+    result = stat(dirName.c_str(),&infoEntry);
     #else
-    lstat(dirName.ascii(),&infoEntry);
+    result = lstat(dirName.c_str(),&infoEntry);
     #endif
+    if (result == -1) {
+      pluginProgress->setError(strerror(errno));
+      return false;
+    }
     if (infoEntry.st_dev!=true)  {
-      label->setNodeValue(newNode,dirName.ascii());
+      label->setNodeValue(newNode,dirName.c_str());
       if (infoEntry.st_size<1)
 	size->setNodeValue(newNode,1);
       else
@@ -152,24 +191,33 @@ struct FileSystem:public ImportModule {
       lastmodif->setNodeValue(newNode,infoEntry.st_mtime);
       lastchange->setNodeValue(newNode,infoEntry.st_ctime);
     }
+
+    pluginProgress->showPreview(false);
+
     unsigned int x = 0, y = 2;
-    readDir(newNode,string(dirName.ascii())+"/", x , y);
+    readDir(newNode,string(dirName.c_str())+"/", x , y);
     double newSize=0;
     Coord tmp(0,0,0);
     if (pluginProgress->state()!=TLP_CANCEL) {
-      Iterator<node> *itN=superGraph->getOutNodes(newNode);
+      Iterator<node> *itN=graph->getOutNodes(newNode);
       while (itN->hasNext()) {
 	node itn=itN->next();
 	newSize+=size->getNodeValue(itn);
 	tmp += layout->getNodeValue(itn);
       } delete itN;
       size->setNodeValue(newNode,newSize);
-      tmp /= superGraph->outdeg(newNode);
+      tmp /= graph->outdeg(newNode);
       tmp[1] = 0;
       layout->setNodeValue(newNode, tmp);
+      node itn;
+      forEach(itn, graph->getNodes()) {
+	tmp = layout->getNodeValue(itn);
+	tmp[1] = -tmp[1];
+	layout->setNodeValue(itn, tmp);
+      }
     }
     return pluginProgress->state()!=TLP_CANCEL;
   }
 };
-
-  IMPORTPLUGINOFGROUP(FileSystem,"FileSystem", "Auber", "16/12/2002", "0", "0", "1", "Misc")
+/*@}*/
+IMPORTPLUGINOFGROUP(FileSystem, "File System Directory", "Auber", "16/12/2002", "", "1.1", "Misc")
