@@ -1,6 +1,18 @@
+//-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 #include <iostream>
 #include <string>
 #include <list>
+#include <string.h>
 
 /*
   Il faut ajouter la gestion correcte des erreurs et cest nikel.
@@ -85,6 +97,7 @@ struct GMLTokenParser {
 //=====================================================================================
 struct GMLBuilder
 {
+  virtual ~GMLBuilder() {}
   virtual bool addBool(const std::string &,const bool)=0;
   virtual bool addInt(const std::string &,const int)=0;
   virtual bool addDouble(const std::string &,const double)=0;
@@ -139,7 +152,6 @@ struct GMLParser
 {
   std::list<GMLBuilder *> builderStack;
   std::istream &inputStream;
-  GMLTokenParser *tokenParser;
 
   GMLParser(std::istream &inputStream,GMLBuilder *builder):inputStream(inputStream)
   {
@@ -155,75 +167,75 @@ struct GMLParser
   }
   bool parse()
   {
-    tokenParser=new GMLTokenParser(inputStream);
+    GMLTokenParser tokenParser(inputStream);
     GMLToken currentToken;
     GMLToken nextToken;
     GMLValue currentValue;
     GMLValue nextValue;
-    while ((currentToken=tokenParser->nextToken(currentValue))!=ENDOFSTREAM)
-      {
-	switch (currentToken)
+    while ((currentToken=tokenParser.nextToken(currentValue))!=ENDOFSTREAM) {
+      switch (currentToken) {
+      case STRINGTOKEN:
+	nextToken=tokenParser.nextToken(nextValue);
+	switch (nextToken) {
+	case OPENTOKEN:
+	  GMLBuilder *newBuilder;
+	  if (builderStack.front()->addStruct(currentValue.str,newBuilder))
+	    {
+	      builderStack.push_front(newBuilder);
+	    }
+	  else
+	    {
+	      return false;
+	    }
+	  break;
+	case BOOLTOKEN:
+	  if (!builderStack.front()->addBool(currentValue.str,nextValue.boolean)) 
+	    {
+	      std::cerr << "Error parsing stream line :" << tokenParser.curLine << " char : " << tokenParser.curChar << std::endl;
+	      return false;
+	    }
+	  break;
+	case INTTOKEN:
+	  if (!builderStack.front()->addInt(currentValue.str,nextValue.integer)) 
+	    {
+	      std::cerr << "Error parsing stream line :" << tokenParser.curLine << " char : " << tokenParser.curChar << std::endl;
+	      return false;
+	    }
+	  break;
+	case DOUBLETOKEN:
+	  if (!builderStack.front()->addDouble(currentValue.str,nextValue.real)) 
+	    {
+	      std::cerr << "Error parsing stream line :" << tokenParser.curLine << " char : " << tokenParser.curChar << std::endl;
+	      return false;
+	    }
+	  break;
+	case STRINGTOKEN:
+	  if (!builderStack.front()->addString(currentValue.str,nextValue.str)) 
+	    {
+	      std::cerr << "Error parsing stream line :" << tokenParser.curLine << " char : " << tokenParser.curChar << std::endl;
+	      return false;
+	    }
+	  break;
+	case ERRORINFILE:return false;break;
+	case ENDOFSTREAM:return true;break;
+	default:break;
+	}
+	break;
+      case CLOSETOKEN:
+	if (builderStack.front()->close())
+	  delete builderStack.front();
+	else
 	  {
-	  case STRINGTOKEN:
-	    nextToken=tokenParser->nextToken(nextValue);
-	    switch (nextToken)
-	      {
-	      case OPENTOKEN:
-		GMLBuilder *newBuilder;
-		if (builderStack.front()->addStruct(currentValue.str,newBuilder))
-		  {
-		    builderStack.push_front(newBuilder);
-		  }
-		else
-		  {
-		    return false;
-		  }
-		break;
-	      case BOOLTOKEN:
-		if (!builderStack.front()->addBool(currentValue.str,nextValue.boolean)) 
-		  {
-		    std::cerr << "Error parsing stream line :" << tokenParser->curLine << " char : " << tokenParser->curChar << std::endl;
-		    return false;
-		  }
-		break;
-	      case INTTOKEN:
-		if (!builderStack.front()->addInt(currentValue.str,nextValue.integer)) 
-		  {
-		    std::cerr << "Error parsing stream line :" << tokenParser->curLine << " char : " << tokenParser->curChar << std::endl;
-		    return false;
-		  }
-		break;
-	      case DOUBLETOKEN:
-		if (!builderStack.front()->addDouble(currentValue.str,nextValue.real)) 
-		  {
-		    std::cerr << "Error parsing stream line :" << tokenParser->curLine << " char : " << tokenParser->curChar << std::endl;
-		    return false;
-		  }
-		break;
-	      case STRINGTOKEN:
-		if (!builderStack.front()->addString(currentValue.str,nextValue.str)) 
-		  {
-		    std::cerr << "Error parsing stream line :" << tokenParser->curLine << " char : " << tokenParser->curChar << std::endl;
-		    return false;
-		  }
-		break;
-	      case ERRORINFILE:return false;break;
-	      case ENDOFSTREAM:return true;break;
-	      default:break;
-	      }
-	    break;
-	  case CLOSETOKEN:
-	    if (builderStack.front()->close())
-	      delete builderStack.front();
-	    else
-	      {
-		std::cerr << "Error parsing stream line :" << tokenParser->curLine << " char : " << tokenParser->curChar << std::endl;
-		return false;
-	      }
-	    builderStack.pop_front();
-	    break;
-	  }	    
-      }
+	    std::cerr << "Error parsing stream line :" << tokenParser.curLine << " char : " << tokenParser.curChar << std::endl;
+	    return false;
+	  }
+	builderStack.pop_front();
+	break;
+      default:
+	std::cerr << "Error parsing stream line :" << tokenParser.curLine << " char : " << tokenParser.curChar << std::endl;
+	return false;
+      }	    
+    }
     return true;
   }
 };
