@@ -1,3 +1,14 @@
+//-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 /* A Bison parser, made by GNU Bison 2.0.  */
 
 /* Skeleton parser for Yacc-like parsing with Bison,
@@ -169,7 +180,7 @@ struct DOT_ATTR {
     STYLE = (1<<13)
   };
 
-  uint mask; // defined mask
+  unsigned int mask; // defined mask
 
   Coord layout;
   int shape;
@@ -278,8 +289,8 @@ struct DOT_ATTR {
       mask |= DEPTH;
     }
     else if( inId == "shape" ) {
-      uint N = sizeof(ShapeAttrA) / sizeof(ShapeAttr);
-      for( uint i = 0 ; i < N ; i++ ) {
+      unsigned int N = sizeof(ShapeAttrA) / sizeof(ShapeAttr);
+      for( unsigned int i = 0 ; i < N ; i++ ) {
 	if( !strcasecmp(ShapeAttrA[i].name,inValue.c_str()) ) {
 	  shape = ShapeAttrA[i].idx;
 	  mask |= SHAPE;
@@ -332,7 +343,7 @@ struct DOT_YYType {
 struct DOT_YY {
   DOT_YY() : sg(0), isDirected(true), isStrict(true) {}
 
-  SuperGraph * sg;
+  Graph * sg;
   NodeMap nodeMap;
   bool isDirected; // directed graph ?
   bool isStrict; // strict graph ?
@@ -362,8 +373,8 @@ struct DOT_YY {
     EdgeA edgeA;
     bool di = isStrict ? isDirected : ( inOp == "->" );
     // produit cartesien A x B
-    for( uint i = 0 ; i < inA.size(); i++ ) {
-      for( uint j = 0 ; j < inB.size() ; j++ ) {
+    for( unsigned int i = 0 ; i < inA.size(); i++ ) {
+      for( unsigned int j = 0 ; j < inB.size() ; j++ ) {
 	edgeA.push_back( sg->addEdge(inA[i],inB[j]) );
 	if( !di )
 	  edgeA.push_back( sg->addEdge(inB[j],inA[i]) );
@@ -404,17 +415,17 @@ struct DOT_YY {
     // Layout
 
     if( inAttr.mask & DOT_ATTR::LAYOUT ) {
-      LayoutProxy * layoutP = sg->getProperty<LayoutProxy>(TLP_LAYOUT_PROXY_NAME);
-      for( uint i = 0 ; i < inA.size() ; i++ )
+      LayoutProperty * layoutP = sg->getProperty<LayoutProperty>(TLP_LAYOUT_PROXY_NAME);
+      for( unsigned int i = 0 ; i < inA.size() ; i++ )
 	layoutP->setNodeValue( inA[i], inAttr.layout );
     }
 
     // Label
 
     if( (inAttr.mask & DOT_ATTR::LABEL) && inAttr.label.size() ) {
-      StringProxy * stringP = sg->getProperty<StringProxy>(TLP_LABEL_PROXY_NAME);
-      StringProxy * string2P = sg->getProperty<StringProxy>(TLP_EXTLABEL_PROXY_NAME);
-      for( uint i = 0 ; i < inA.size() ; i++ ) {
+      StringProperty * stringP = sg->getProperty<StringProperty>(TLP_LABEL_PROXY_NAME);
+      StringProperty * string2P = sg->getProperty<StringProperty>(TLP_EXTLABEL_PROXY_NAME);
+      for( unsigned int i = 0 ; i < inA.size() ; i++ ) {
 	stringP->setNodeValue( inA[i], inAttr.label );
 	string2P->setNodeValue( inA[i], inAttr.label );
       }
@@ -427,33 +438,33 @@ struct DOT_YY {
       if( inAttr.mask & DOT_ATTR::WIDTH ) s.setW( inAttr.size.getW() );
       if( inAttr.mask & DOT_ATTR::HEIGHT ) s.setH( inAttr.size.getH() );
       if( inAttr.mask & DOT_ATTR::DEPTH ) s.setD( inAttr.size.getD() );
-      SizesProxy * sizeP = sg->getProperty<SizesProxy>(TLP_SIZE_PROXY_NAME);
-      for( uint i = 0 ; i < inA.size() ; i++ )
+      SizeProperty * sizeP = sg->getProperty<SizeProperty>(TLP_SIZE_PROXY_NAME);
+      for( unsigned int i = 0 ; i < inA.size() ; i++ )
 	sizeP->setNodeValue( inA[i], s );
     }
 
     // Color
 
     if( inAttr.mask & DOT_ATTR::FILL_COLOR ) {
-      ColorsProxy * colP = sg->getProperty<ColorsProxy>(TLP_COLOR_PROXY_NAME);
-      for( uint i = 0 ; i < inA.size() ; i++ )
+      ColorProperty * colP = sg->getProperty<ColorProperty>(TLP_COLOR_PROXY_NAME);
+      for( unsigned int i = 0 ; i < inA.size() ; i++ )
 	colP->setNodeValue( inA[i], inAttr.fillcolor );
     }
     if( inAttr.mask & DOT_ATTR::COLOR ) {
-      ColorsProxy * colP = sg->getProperty<ColorsProxy>(TLP_BORDERCOLOR_PROXY_NAME);
-      for( uint i = 0 ; i < inA.size() ; i++ )
+      ColorProperty * colP = sg->getProperty<ColorProperty>(TLP_BORDERCOLOR_PROXY_NAME);
+      for( unsigned int i = 0 ; i < inA.size() ; i++ )
 	colP->setNodeValue( inA[i], inAttr.color );
     }
     if( inAttr.mask & DOT_ATTR::FONT_COLOR ) {
-      ColorsProxy * colP = sg->getProperty<ColorsProxy>(TLP_FONTCOLOR_PROXY_NAME);
-      for( uint i = 0 ; i < inA.size() ; i++ )
+      ColorProperty * colP = sg->getProperty<ColorProperty>(TLP_FONTCOLOR_PROXY_NAME);
+      for( unsigned int i = 0 ; i < inA.size() ; i++ )
 	colP->setNodeValue( inA[i], inAttr.fontcolor );
     }
 
     // Shape
     {
-      IntProxy * shapeP = sg->getProperty<IntProxy>(TLP_SHAPE_PROXY_NAME);
-      for( uint i = 0 ; i < inA.size() ; i++ )
+      IntegerProperty * shapeP = sg->getProperty<IntegerProperty>(TLP_SHAPE_PROXY_NAME);
+      for( unsigned int i = 0 ; i < inA.size() ; i++ )
 	if( inAttr.mask & DOT_ATTR::SHAPE )
 	  shapeP->setNodeValue( inA[i], inAttr.shape );
 	else
@@ -463,16 +474,16 @@ struct DOT_YY {
     // Comment
 
     if( inAttr.mask & DOT_ATTR::COMMENT ) {
-      StringProxy * cmntP = sg->getProperty<StringProxy>(TLP_COMMENT_PROXY_NAME);
-      for( uint i = 0 ; i < inA.size() ; i++ )
+      StringProperty * cmntP = sg->getProperty<StringProperty>(TLP_COMMENT_PROXY_NAME);
+      for( unsigned int i = 0 ; i < inA.size() ; i++ )
 	cmntP->setNodeValue( inA[i], inAttr.comment );
     }
 
     // URL
 
     if( (inAttr.mask & DOT_ATTR::URL) && inAttr.url.size() ) {
-      StringProxy * urlP = sg->getProperty<StringProxy>(TLP_URL_PROXY_NAME);
-      for( uint i = 0 ; i < inA.size() ; i++ )
+      StringProperty * urlP = sg->getProperty<StringProperty>(TLP_URL_PROXY_NAME);
+      for( unsigned int i = 0 ; i < inA.size() ; i++ )
 	urlP->setNodeValue( inA[i], inAttr.url );
     }
   }
@@ -484,9 +495,9 @@ struct DOT_YY {
     // Label
 
     if( (inAttr.mask & DOT_ATTR::LABEL) && inAttr.label.size() ) {
-      StringProxy * stringP = sg->getProperty<StringProxy>(TLP_LABEL_PROXY_NAME);
-      StringProxy * string2P = sg->getProperty<StringProxy>(TLP_EXTLABEL_PROXY_NAME);
-      for( uint i = 0 ; i < inA.size() ; i++ ) {
+      StringProperty * stringP = sg->getProperty<StringProperty>(TLP_LABEL_PROXY_NAME);
+      StringProperty * string2P = sg->getProperty<StringProperty>(TLP_EXTLABEL_PROXY_NAME);
+      for( unsigned int i = 0 ; i < inA.size() ; i++ ) {
 	stringP->setEdgeValue( inA[i], inAttr.label );
 	string2P->setEdgeValue( inA[i], inAttr.label );
       }
@@ -495,39 +506,39 @@ struct DOT_YY {
     // Head-Label
 
     if( (inAttr.mask & DOT_ATTR::HEAD_LABEL) && inAttr.headLabel.size() ) {
-      StringProxy * labelP = sg->getProperty<StringProxy>(TLP_HEAD_LABEL_PROXY_NAME);
-      for( uint i = 0 ; i < inA.size() ; i++ )
+      StringProperty * labelP = sg->getProperty<StringProperty>(TLP_HEAD_LABEL_PROXY_NAME);
+      for( unsigned int i = 0 ; i < inA.size() ; i++ )
 	labelP->setEdgeValue( inA[i], inAttr.headLabel );
     }
 
     // Tail-Label
 
     if( (inAttr.mask & DOT_ATTR::TAIL_LABEL) && inAttr.tailLabel.size() ) {
-      StringProxy * labelP = sg->getProperty<StringProxy>(TLP_TAIL_LABEL_PROXY_NAME);
-      for( uint i = 0 ; i < inA.size() ; i++ )
+      StringProperty * labelP = sg->getProperty<StringProperty>(TLP_TAIL_LABEL_PROXY_NAME);
+      for( unsigned int i = 0 ; i < inA.size() ; i++ )
 	labelP->setEdgeValue( inA[i], inAttr.tailLabel );
     }
 
     // Color
     if( inAttr.mask & DOT_ATTR::COLOR ) {
-      ColorsProxy * colP = sg->getProperty<ColorsProxy>(TLP_COLOR_PROXY_NAME);
-      for( uint i = 0 ; i < inA.size() ; i++ )
+      ColorProperty * colP = sg->getProperty<ColorProperty>(TLP_COLOR_PROXY_NAME);
+      for( unsigned int i = 0 ; i < inA.size() ; i++ )
 	colP->setEdgeValue( inA[i], inAttr.color );
     }
 
     // Comment
 
     if( inAttr.mask & DOT_ATTR::COMMENT ) {
-      StringProxy * cmntP = sg->getProperty<StringProxy>(TLP_COMMENT_PROXY_NAME);
-      for( uint i = 0 ; i < inA.size() ; i++ )
+      StringProperty * cmntP = sg->getProperty<StringProperty>(TLP_COMMENT_PROXY_NAME);
+      for( unsigned int i = 0 ; i < inA.size() ; i++ )
 	cmntP->setEdgeValue( inA[i], inAttr.comment );
     }
 
     // URL
 
     if( (inAttr.mask & DOT_ATTR::URL) && inAttr.url.size() ) {
-      StringProxy * urlP = sg->getProperty<StringProxy>(TLP_URL_PROXY_NAME);
-      for( uint i = 0 ; i < inA.size() ; i++ )
+      StringProperty * urlP = sg->getProperty<StringProperty>(TLP_URL_PROXY_NAME);
+      for( unsigned int i = 0 ; i < inA.size() ; i++ )
 	urlP->setEdgeValue( inA[i], inAttr.url );
     }
   }
@@ -1155,7 +1166,7 @@ int yydebug;
 #  if defined (__GLIBC__) && defined (_STRING_H)
 #   define yystrlen strlen
 #  else
-/* Return the length of YYSTR.  */
+/* Returns the length of YYSTR.  */
 static YYSIZE_T
 #   if defined (__STDC__) || defined (__cplusplus)
 yystrlen (const char *yystr)
