@@ -1,4 +1,14 @@
 //-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 #ifndef _BUBBLE_CIRCULARLAYOUT_H
 #define _BUBBLE_CIRCULARLAYOUT_H
 
@@ -6,7 +16,6 @@
 
 /** \addtogroup layout */
 /*@{*/
-/// Circular.h - An implementation of a circurlar layout.
 /** 
  * This plugin is an implementation of a circular layout that takes
  * node size into account.  It manages size of nodes and use a standard dfs
@@ -30,9 +39,9 @@
  * Daniel Archambault The University of British Columbia:
  * Email:  archam@cs.ubc.ca
  */
-class Circular:public Layout { 
+class Circular:public tlp::LayoutAlgorithm { 
 public:
-  Circular(const PropertyContext &);
+  Circular(const tlp::PropertyContext &);
   bool run();
 };
 /*@}*/
