@@ -1,3 +1,14 @@
+//-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 /***************************************
 
   Power iteration algorithm.
@@ -37,7 +48,6 @@ void mat_mult_vec(double ** mat, int dim1, int dim2, double * vec, double *resul
 
 void power_iteration(double ** square_mat, int n, int neigs, double ** eigs, double * evals) {
   int i,j;
-  int converged = 0;
   double *tmp_vec = new double[n]; 
   double *last_vec = new double[n];
   double * curr_vector;
