@@ -1,91 +1,74 @@
+//-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 #include <string>
 #include <cassert>
 #include <math.h> 
 #include <stack>
-#include <tulip/AcyclicTest.h>
-#include <tulip/TreeTest.h>
-#include <tulip/MethodFactory.h>
-#include <tulip/LayoutProxy.h>
-#include <tulip/SelectionProxy.h>
-#include <tulip/GraphTools.h>
-#include <tulip/TlpTools.h>
-#include <tulip/ForEach.h>
 #include <tulip/SortIterator.h>
 #include "HierarchicalGraph.h"
+#include "DatasetTools.h"
 
 
-LAYOUTPLUGINOFGROUP(HierarchicalGraph,"Hierarchical Graph","David Auber","23/05/2000","Alpha","0","1","Hierarchical");
+LAYOUTPLUGINOFGROUP(HierarchicalGraph,"Hierarchical Graph","David Auber","23/05/2000","Alpha","1.0","Hierarchical");
 
 using namespace std;
+using namespace tlp;
 
 static const int NB_UPDOWN_SWEEP = 4;
 
 //================================================================================
 namespace {
   const char * paramHelp[] = {
-    // nodeSize
-    HTML_HELP_OPEN() \
-    HTML_HELP_DEF( "type", "SizeProxy" ) \
-    HTML_HELP_DEF( "values", "An existing size property" ) \
-    HTML_HELP_DEF( "default", "viewSize" ) \
-    HTML_HELP_BODY() \
-    "This parameter defines the property used for node's sizes." \
-    HTML_HELP_CLOSE(),
     //Orientation
     HTML_HELP_OPEN()				 \
     HTML_HELP_DEF( "type", "String Collection" ) \
     HTML_HELP_DEF( "default", "horizontal" )	 \
     HTML_HELP_BODY() \
     "This parameter enables to choose the orientation of the drawing"	\
-    HTML_HELP_CLOSE(),
-    //Spacing
-    HTML_HELP_OPEN()				 \
-    HTML_HELP_DEF( "type", "float" ) \
-    HTML_HELP_DEF( "default", "64." )	 \
-    HTML_HELP_BODY() \
-    "This parameter enables to set up the minimum space between two layers in the drawing" \
-    HTML_HELP_CLOSE(),
-    //Spacing
-    HTML_HELP_OPEN()				 \
-    HTML_HELP_DEF( "type", "float" ) \
-    HTML_HELP_DEF( "default", "18." )	 \
-    HTML_HELP_BODY() \
-    "This parameter enables to set up the minimum space between two nodes in the same layer" \
     HTML_HELP_CLOSE()
   };
 }
 //================================================================================
 #define ORIENTATION "horizontal;vertical;"
 //================================================================================
-HierarchicalGraph::HierarchicalGraph(const PropertyContext &context):Layout(context) {
-  addParameter<SizesProxy>("nodeSize",paramHelp[0],"viewSize");
-  addParameter<StringCollection> ("orientation", paramHelp[1], ORIENTATION );
-  addParameter<float> ("layer spacing", paramHelp[2], "64." );
-  addParameter<float> ("node spacing", paramHelp[3], "18." );
+HierarchicalGraph::HierarchicalGraph(const PropertyContext &context):LayoutAlgorithm(context) {
+  addNodeSizePropertyParameter(this);
+  addParameter<StringCollection> ("orientation", paramHelp[0], ORIENTATION );
+  addSpacingParameters(this);
+  addDependency<DoubleAlgorithm>("Dag Level", "1.0");
+  addDependency<LayoutAlgorithm>("Hierarchical Tree (R-T Extended)", "1.0");
 }
 //================================================================================
 HierarchicalGraph::~HierarchicalGraph() {}
 //================================================================================
 class LessThanEdge {
 public:
-  MetricProxy *metric;
-  SuperGraph *sg;
+  DoubleProperty *metric;
+  Graph *sg;
   bool operator() (edge e1, edge e2) {
     return (metric->getNodeValue(sg->source(e1)) < metric->getNodeValue(sg->source(e2)));
   }
 };
 //================================================================================
-void HierarchicalGraph::buildGrid(SuperGraph *graph){
+void HierarchicalGraph::buildGrid(Graph *sg){
   //  cerr << __PRETTY_FUNCTION__  << endl;
-  bool resultBool;
   string erreurMsg;
-  MetricProxy dagLevel(graph);
-  if(!graph->computeProperty("DagLevel", &dagLevel,erreurMsg)) {
+  DoubleProperty dagLevel(sg);
+  if(!sg->computeProperty("Dag Level", &dagLevel,erreurMsg)) {
     cerr << "[ERROR] : " << erreurMsg << __PRETTY_FUNCTION__ << endl;
     return;
   }
   node n;
-  forEach(n, graph->getNodes()) {
+  forEach(n, sg->getNodes()) {
     unsigned int level=(unsigned int)dagLevel.getNodeValue(n);
     while (level>=grid.size()) grid.push_back(vector<node>());
     embedding->setNodeValue(n, grid[level].size());
@@ -94,25 +77,25 @@ void HierarchicalGraph::buildGrid(SuperGraph *graph){
   //  cerr << __PRETTY_FUNCTION__  << endl;
 }
 //================================================================================
-unsigned int HierarchicalGraph::degree(SuperGraph *superGraph,node n,bool sense) {
+unsigned int HierarchicalGraph::degree(Graph *sg,node n,bool sense) {
   if (sense)
-    return (superGraph->outdeg(n));
+    return (sg->outdeg(n));
   else
-    return (superGraph->indeg(n));
+    return (sg->indeg(n));
 }
 //================================================================================
 //If sense==true fixed_layer is freeLayer+1 else freeLayer-1
 //Compute barycenter heuristique
 
-void HierarchicalGraph::twoLayerCrossReduction(SuperGraph *superGraph,unsigned int freeLayer,bool sense){
+void HierarchicalGraph::twoLayerCrossReduction(Graph *sg,unsigned int freeLayer,bool sense){
   vector<node>::const_iterator it;
   for (it = grid[freeLayer].begin(); it!=grid[freeLayer].end(); ++it) {
     node n = *it;
     double sum = embedding->getNodeValue(n);
     node it;
-    forEach(it, superGraph->getInOutNodes(n))
+    forEach(it, sg->getInOutNodes(n))
       sum += embedding->getNodeValue(it);
-    embedding->setNodeValue(n, sum / (double(superGraph->deg(n)) + 1.0 ) );
+    embedding->setNodeValue(n, sum / (double(sg->deg(n)) + 1.0 ) );
   }
   /*
   stable_sort(grid[freeLayer].begin(), grid[freeLayer].end(), lessNode);
@@ -125,22 +108,22 @@ void HierarchicalGraph::twoLayerCrossReduction(SuperGraph *superGraph,unsigned i
 }
 
 /*
-void HierarchicalGraph::twoLayerCrossReduction(SuperGraph *superGraph,unsigned int freeLayer,bool sense){
+void HierarchicalGraph::twoLayerCrossReduction(Graph *sg,unsigned int freeLayer,bool sense){
   vector<node>::const_iterator it;
   for (it = grid[freeLayer].begin(); it!=grid[freeLayer].end(); ++it) {
     node n = *it;
-    if (degree(superGraph,  n, sense)>0) {
+    if (degree(sg,  n, sense)>0) {
       double sum = embedding->getNodeValue(n);
       Iterator<node>*itN;
       if (sense) 
-	itN=superGraph->getOutNodes(n);
+	itN=sg->getOutNodes(n);
       else
-	itN=superGraph->getInNodes(n);
+	itN=sg->getInNodes(n);
       while(itN->hasNext()) {
 	node itn=itN->next();
 	sum += embedding->getNodeValue(itn);
       } delete itN;
-      embedding->setNodeValue(n,sum/((double)degree(superGraph,n,sense) + 1.0));
+      embedding->setNodeValue(n,sum/((double)degree(sg,n,sense) + 1.0));
     }
     else {
       //      embedding->setNodeValue(n, 10000);
@@ -158,25 +141,25 @@ void HierarchicalGraph::twoLayerCrossReduction(SuperGraph *superGraph,unsigned i
 */
 //================================================================================
 //Set initial position using a DFS
-void HierarchicalGraph::initCross(SuperGraph *superGraph, node n, MutableContainer<bool> &visited, int id) {
+void HierarchicalGraph::initCross(Graph *sg, node n, MutableContainer<bool> &visited, int id) {
   if (visited.get(n.id)) return;
   visited.set(n.id, true);
   embedding->setNodeValue(n, id);
   node it;
-  forEach(it, superGraph->getOutNodes(n)) {
-    initCross(superGraph, it, visited, id + 1);
+  forEach(it, sg->getOutNodes(n)) {
+    initCross(sg, it, visited, id + 1);
   }
 }
 //================================================================================
 // Do layer by layer sweep to reduce crossings in K-Layer graph
-void HierarchicalGraph::crossReduction(SuperGraph *graph){
+void HierarchicalGraph::crossReduction(Graph *sg){
 
-  node tmp = graph->addNode();
+  node tmp = sg->addNode();
   embedding->setNodeValue(tmp, 0);
   node it;
-  forEach(it, graph->getNodes()){
-    if (graph->outdeg(it) == 0)
-      graph->addEdge(it, tmp);
+  forEach(it, sg->getNodes()){
+    if (sg->outdeg(it) == 0)
+      sg->addEdge(it, tmp);
   }
   grid.push_back(vector<node>());
   grid[grid.size()-1].push_back(tmp);
@@ -184,10 +167,10 @@ void HierarchicalGraph::crossReduction(SuperGraph *graph){
   MutableContainer<bool> visited;
   visited.setAll(false);
   node root;
-  tlp::getSource(graph,root);
-  initCross(graph, root, visited, 1);
+  tlp::getSource(sg,root);
+  initCross(sg, root, visited, 1);
 
-  for (int a=0; a<grid.size(); ++a) {
+  for (unsigned int a=0; a<grid.size(); ++a) {
     vector<node>::const_iterator it;
     unsigned int j=0;
     stable_sort(grid[a].begin(), grid[a].end(), lessNode);
@@ -202,15 +185,15 @@ void HierarchicalGraph::crossReduction(SuperGraph *graph){
   for (int a=0; a<NB_UPDOWN_SWEEP; ++a) {
     //Up sweeping
     for (int i = maxDepth-1; i>=0; --i) {
-      twoLayerCrossReduction(superGraph,i,true);
+      twoLayerCrossReduction(graph,i,true);
     }
     //Down sweeping
-    for (int i = 0; i<maxDepth; ++i) {
-      twoLayerCrossReduction(superGraph,i,false);
+    for (unsigned int i = 0; i<maxDepth; ++i) {
+      twoLayerCrossReduction(graph,i,false);
     }
   }
 
-  for (int a=0; a<grid.size(); ++a) {
+  for (unsigned int a=0; a<grid.size(); ++a) {
     vector<node>::const_iterator it;
     unsigned int j=0;
     stable_sort(grid[a].begin(), grid[a].end(), lessNode);
@@ -219,37 +202,37 @@ void HierarchicalGraph::crossReduction(SuperGraph *graph){
       j++;
     }
   }
-  graph->delAllNode(tmp);
+  sg->delAllNode(tmp);
   //  cerr << __PRETTY_FUNCTION__  << endl;
 }
 //================================================================================
-void HierarchicalGraph::DagLevelSpanningTree(SuperGraph* graph, MetricProxy *embedding) {
+void HierarchicalGraph::DagLevelSpanningTree(Graph* sg, DoubleProperty *embedding) {
   //  cerr << __PRETTY_FUNCTION__  << endl;
-  assert(AcyclicTest::isAcyclic(graph));
+  assert(AcyclicTest::isAcyclic(sg));
   LessThanEdge tmpL;
   tmpL.metric = embedding;
-  tmpL.sg = graph;
+  tmpL.sg = sg;
   node n;
-  forEach(n, graph->getNodes()) {
-    if (graph->indeg(n) > 1) {
+  forEach(n, sg->getNodes()) {
+    if (sg->indeg(n) > 1) {
       vector<edge> tmpVect;
       edge e;
-      forEach(e, graph->getInEdges(n)) 
+      forEach(e, sg->getInEdges(n)) 
 	tmpVect.push_back(e);
       sort(tmpVect.begin(), tmpVect.end(), tmpL);
       int toKeep = tmpVect.size()/2;
       vector<edge>::const_iterator it;
       for (it=tmpVect.begin(); it!=tmpVect.end(); ++it, --toKeep) {
 	if (toKeep!=0) 
-	  graph->delEdge(*it);
+	  sg->delEdge(*it);
       }
     }
   }
-  assert(TreeTest::isTree(superGraph));
+  assert(TreeTest::isTree(sg));
   //  cerr << __PRETTY_FUNCTION__  << endl;
 }
 //==============================================================================================================
-void HierarchicalGraph::computeEdgeBends(const SuperGraph *mySGraph, LayoutProxy &tmpLayout, 
+void HierarchicalGraph::computeEdgeBends(const Graph *mySGraph, LayoutProperty &tmpLayout, 
 					 const stdext::hash_map<edge,edge> &replacedEdges, const vector<edge> &reversedEdges) {
   //  cerr << "we compute bends on splitted edges" << endl;
   MutableContainer<bool> isReversed;
@@ -263,13 +246,13 @@ void HierarchicalGraph::computeEdgeBends(const SuperGraph *mySGraph, LayoutProxy
     edge end = start;
     Coord p1,p2;
     //we take the first and last point of the replaced edges
-    while (superGraph->target(end) != superGraph->target(toUpdate)) {
-      Iterator<edge> *itE = mySGraph->getOutEdges(superGraph->target(end));
+    while (graph->target(end) != graph->target(toUpdate)) {
+      Iterator<edge> *itE = mySGraph->getOutEdges(graph->target(end));
       end = itE->next();
       delete itE;
     }
-    node firstN = superGraph->target(start);
-    node endN = superGraph->source(end);
+    node firstN = graph->target(start);
+    node endN = graph->source(end);
 
     LineType::RealType edgeLine;
     if (isReversed.get(toUpdate.id)) {
@@ -286,11 +269,11 @@ void HierarchicalGraph::computeEdgeBends(const SuperGraph *mySGraph, LayoutProxy
       edgeLine.push_back(p1); 
       edgeLine.push_back(p2);
     }
-    layoutProxy->setEdgeValue(toUpdate,edgeLine);
+    layoutResult->setEdgeValue(toUpdate,edgeLine);
   }
 }
 //=======================================================================
-void HierarchicalGraph::computeSelfLoops(SuperGraph *mySGraph, LayoutProxy &tmpLayout, std::vector<tlp::SelfLoops> &listSelfLoops) {
+void HierarchicalGraph::computeSelfLoops(Graph *mySGraph, LayoutProperty &tmpLayout, std::vector<tlp::SelfLoops> &listSelfLoops) {
   //cerr << "We compute self loops" << endl;
   while (!listSelfLoops.empty()) {
     tlp::SelfLoops tmp = listSelfLoops.back();
@@ -308,7 +291,7 @@ void HierarchicalGraph::computeSelfLoops(SuperGraph *mySGraph, LayoutProxy &tmpL
     tmpLCoord.push_back(tmpLayout.getNodeValue(tmp.n2));
     for (it = edge3.begin(); it!=edge3.end(); ++it)
       tmpLCoord.push_back(*it);
-    layoutProxy->setEdgeValue(tmp.old,tmpLCoord);
+    layoutResult->setEdgeValue(tmp.old,tmpLCoord);
     mySGraph->delAllNode(tmp.n1);
     mySGraph->delAllNode(tmp.n2);
   }  
@@ -318,24 +301,24 @@ void HierarchicalGraph::computeSelfLoops(SuperGraph *mySGraph, LayoutProxy &tmpL
 
 namespace {
   //============================================================================
-  void dfsRecCall(SuperGraph *graph, vector<node> &vec, MutableContainer<bool> &nodeVisited, node n) {
+  void dfsRecCall(Graph *sg, vector<node> &vec, MutableContainer<bool> &nodeVisited, node n) {
     nodeVisited.set(n.id, true);
     vec.push_back(n);
     node dest;
-    forEach(dest, graph->getInOutNodes(n)) {
+    forEach(dest, sg->getInOutNodes(n)) {
       if (!nodeVisited.get(dest.id)) {
-	dfsRecCall(graph, vec, nodeVisited, dest);
+	dfsRecCall(sg, vec, nodeVisited, dest);
       }
     }
   }
   //============================================================================
-  void buildDfsOrdering(SuperGraph *graph, vector<node> &vec) {
+  void buildDfsOrdering(Graph *sg, vector<node> &vec) {
     MutableContainer<bool> nodeVisited;
     nodeVisited.setAll(false);
     node n;
-    forEach(n, graph->getNodes()) {
+    forEach(n, sg->getNodes()) {
       if (!nodeVisited.get(n.id)) {
-	dfsRecCall(graph, vec, nodeVisited, n);
+	dfsRecCall(sg, vec, nodeVisited, n);
       }
     }
   }
@@ -345,30 +328,29 @@ bool HierarchicalGraph::run() {
   //make acyclic
   /*
   vector<node> order;
-  buildDfsOrdering(superGraph, order);
+  buildDfsOrdering(graph, order);
   MutableContainer<int> orderid;
   for(unsigned int i=0; i< order.size(); ++i) 
     orderid.set(order[i].id, i);
   edge e;
-  forEach(e, superGraph->getEdges()) {
-    node src = superGraph->source(e);
-    node tgt = superGraph->target(e);
+  forEach(e, graph->getEdges()) {
+    node src = graph->source(e);
+    node tgt = graph->target(e);
     if(orderid.get(src.id) > orderid.get(tgt.id))
-      superGraph->reverse(e);
+      graph->reverse(e);
   }
   */    
   //=======================================================================
   // Build a clone of this graph
-  SuperGraph *mySGraph = tlp::newCloneSubGraph(superGraph,"tmp clone");
+  Graph *mySGraph = tlp::newCloneSubGraph(graph,"tmp clone");
 
-  nodeSize = superGraph->getProperty<SizesProxy>("viewSize");
+  nodeSize = graph->getProperty<SizeProperty>("viewSize");
   orientation = "horizontal";
-  float spacing = 64.0;
-  float nodeSpacing = 18;
+  spacing = 64.0;
+  nodeSpacing = 18;
   if (dataSet!=0) {
-    dataSet->get("nodeSize", nodeSize);
-    dataSet->get("layer spacing", spacing);
-    dataSet->get("node spacing", nodeSpacing);
+    getNodeSizePropertyParameter(dataSet, nodeSize);
+    getSpacingParameters(dataSet, nodeSpacing, spacing);
     StringCollection tmp;
     if (dataSet->get("orientation", tmp)) {
       orientation = tmp.getCurrentString();
@@ -378,7 +360,7 @@ bool HierarchicalGraph::run() {
   //rotate size if necessary
   if (orientation == "horizontal") {
     node n;
-    forEach(n, superGraph->getNodes()) {
+    forEach(n, graph->getNodes()) {
       Size tmp = nodeSize->getNodeValue(n);
       nodeSize->setNodeValue(n, Size(tmp[1], tmp[0], tmp[2]));
     }
@@ -396,19 +378,19 @@ bool HierarchicalGraph::run() {
   //========================================================================
   list<node> properAddedNodes;
   stdext::hash_map<edge,edge> replacedEdges;
-  IntProxy *edgeLength = 0;
+  IntegerProperty *edgeLength = 0;
   if (!TreeTest::isTree(mySGraph)) {
     //We transform the dag in a proper dag
-    edgeLength = new IntProxy(mySGraph);
+    edgeLength = new IntegerProperty(mySGraph);
     tlp::makeProperDag(mySGraph,properAddedNodes,replacedEdges,edgeLength);
     //we compute metric for cross reduction
-    MetricProxy embed(mySGraph);
+    DoubleProperty embed(mySGraph);
     embedding = &embed;
     lessNode.metric = embedding;
     buildGrid(mySGraph);
     crossReduction(mySGraph);
     node n;
-    forEach(n, superGraph->getNodes()) {
+    forEach(n, graph->getNodes()) {
       vector<edge> order;
       edge e;
       forEach(e, new SortTargetEdgeIterator(mySGraph->getOutEdges(n),mySGraph, embedding)) {
@@ -419,7 +401,7 @@ bool HierarchicalGraph::run() {
     //We extract a spanning tree from the proper dag.
     DagLevelSpanningTree(mySGraph, &embed);
   } else {
-    MetricProxy embed(mySGraph);
+    DoubleProperty embed(mySGraph);
     embedding = &embed;
     buildGrid(mySGraph);
   }
@@ -427,41 +409,42 @@ bool HierarchicalGraph::run() {
   //We draw the tree using a tree drawing algorithm
   bool resultBool;
   string erreurMsg;
-  LayoutProxy tmpLayout(superGraph);
+  LayoutProperty tmpLayout(graph);
   DataSet tmp;
-  tmp.set("nodeSize", nodeSize);
-  tmp.set("edgeLength", edgeLength);
+  tmp.set("node size", nodeSize);
   tmp.set("layer spacing", spacing);
   tmp.set("node spacing", nodeSpacing);
   if (edgeLength!=0)
-    tmp.set("use length", true);
-  else
-    tmp.set("use length", false);
-  tmp.set("ortogonal", false);
+    tmp.set("edge length", edgeLength);
+  tmp.set("orthogonal", false);
   StringCollection tmpS("vertical;horizontal;");
   tmpS.setCurrent("vertical");
   tmp.set("orientation", tmpS);
   resultBool = mySGraph->computeProperty("Hierarchical Tree (R-T Extended)", &tmpLayout, erreurMsg, 0, &tmp);
+
+  if (edgeLength)
+    delete edgeLength;
+
   assert(resultBool);
   
   
   node n;
-  forEach(n, superGraph->getNodes()) {
-    layoutProxy->setNodeValue(n, tmpLayout.getNodeValue(n));
+  forEach(n, graph->getNodes()) {
+    layoutResult->setNodeValue(n, tmpLayout.getNodeValue(n));
   }
 
   computeEdgeBends(mySGraph, tmpLayout, replacedEdges, reversedEdges);
   computeSelfLoops(mySGraph, tmpLayout, listSelfLoops);
   
   for (vector<edge>::const_iterator it=reversedEdges.begin(); it!=reversedEdges.end(); ++it) {
-    superGraph->reverse(*it);
+    graph->reverse(*it);
   }
   mySGraph->delAllNode(startNode);
   while(!properAddedNodes.empty()) {
     mySGraph->delAllNode(properAddedNodes.back());
     properAddedNodes.pop_back();
   }
-  superGraph->delSubGraph(mySGraph);
+  graph->delSubGraph(mySGraph);
 
   //post processing 
   //Prevent edge node overlaping
@@ -472,7 +455,7 @@ bool HierarchicalGraph::run() {
     levelMaxSize[i] = 0;
     for (unsigned int j= 0; j < grid[i].size(); ++ j) {
       node n = grid[i][j];
-      if(superGraph->isElement(n)) {
+      if(graph->isElement(n)) {
 	nodeLevel.set(n.id, i);
 	Size tmp = nodeSize->getNodeValue(n);
 	levelMaxSize[i] = std::max(levelMaxSize[i], tmp[1]);
@@ -480,26 +463,26 @@ bool HierarchicalGraph::run() {
     }
   }
   edge e;
-  forEach(e, superGraph->getEdges()) {
-    node src = superGraph->source(e);
-    node tgt = superGraph->target(e);
+  forEach(e, graph->getEdges()) {
+    node src = graph->source(e);
+    node tgt = graph->target(e);
     if (src == tgt) {
       continue;
     }
-    float rev = 1.0;
+    float rev = -1.0;
     if (nodeLevel.get(src.id)>nodeLevel.get(tgt.id)) {
-      rev = -1.0;
+      rev = 1.0;
     }
-    Coord srcPos = layoutProxy->getNodeValue(src);
-    Coord tgtPos = layoutProxy->getNodeValue(tgt);
-    vector<Coord> old = layoutProxy->getEdgeValue(e);
+    Coord srcPos = layoutResult->getNodeValue(src);
+    Coord tgtPos = layoutResult->getNodeValue(tgt);
+    vector<Coord> old = layoutResult->getEdgeValue(e);
     if (old.size() == 0) {
       vector<Coord> pos(2);
       srcPos[1] += rev*(levelMaxSize[nodeLevel.get(src.id)]/2.0 + spacing/4.);
       tgtPos[1] -= rev*(levelMaxSize[nodeLevel.get(tgt.id)]/2.0 + spacing/4.);
       pos[0] = srcPos;
       pos[1] = tgtPos;
-      layoutProxy->setEdgeValue(e, pos);
+      layoutResult->setEdgeValue(e, pos);
     }
     else {
       vector<Coord> pos(4);
@@ -513,38 +496,46 @@ bool HierarchicalGraph::run() {
       pos[1] = src2Pos;
       pos[2] = tgt2Pos;
       pos[3] = tgtPos;
-      layoutProxy->setEdgeValue(e, pos);
+      layoutResult->setEdgeValue(e, pos);
     }
   }
   
   //post processing align nodes
-  forEach(n, superGraph->getNodes()) {
-    Coord tmp = layoutProxy->getNodeValue(n);
+  forEach(n, graph->getNodes()) {
+    Coord tmp = layoutResult->getNodeValue(n);
     Size tmpS = nodeSize->getNodeValue(n);
     tmp[1] -= (levelMaxSize[nodeLevel.get(n.id)] - tmpS[1]) / 2.0;
-    layoutProxy->setNodeValue(n, tmp);
+    layoutResult->setNodeValue(n, tmp);
   }
 
   //rotate layout and size
   if (orientation == "horizontal") {
     node n;
-    forEach(n, superGraph->getNodes()) {
+    forEach(n, graph->getNodes()) {
       Size  tmp = nodeSize->getNodeValue(n);
       nodeSize->setNodeValue(n, Size(tmp[1], tmp[0], tmp[2]));
-      Coord tmpC = layoutProxy->getNodeValue(n);
-      layoutProxy->setNodeValue(n, Coord(-tmpC[1], tmpC[0], tmpC[2]));
+      Coord tmpC = layoutResult->getNodeValue(n);
+      layoutResult->setNodeValue(n, Coord(-tmpC[1], tmpC[0], tmpC[2]));
     }
     edge e;
-    forEach(e, superGraph->getEdges()) {
-      LineType::RealType tmp = layoutProxy->getEdgeValue(e);
+    forEach(e, graph->getEdges()) {
+      LineType::RealType tmp = layoutResult->getEdgeValue(e);
       LineType::RealType tmp2;
       LineType::RealType::iterator it;
       for (it = tmp.begin(); it!= tmp.end(); ++it) {
 	tmp2.push_back(Coord(-(*it)[1], (*it)[0], (*it)[2]));
       }
-      layoutProxy->setEdgeValue(e, tmp2);
+      layoutResult->setEdgeValue(e, tmp2);
     }
   }
+
+  // if in tulip gui, keep node size updates
+  // the test below indicates if we are invoked from the tulip gui
+  // cf viewGl.cpp & GlGraphInputData.cpp
+  LayoutProperty* elementLayout;
+  if (graph->getAttribute("viewLayout", elementLayout))
+    graph->push();
+
   return true;
 }
 
