@@ -1,19 +1,30 @@
+//-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 #ifndef ORIENTABLESIZE_H
 #define ORIENTABLESIZE_H
 
 #include <tulip/Size.h>
 class OrientableSizeProxy;
 
-class OrientableSize: public Size {
+class OrientableSize: public tlp::Size {
 public:  
 
     OrientableSize(OrientableSizeProxy* fatherParam, const float width = 0,
                    const float height = 0, const float depth = 0);
-    OrientableSize(OrientableSizeProxy* fatherParam, const Size& size);
+    OrientableSize(OrientableSizeProxy* fatherParam, const tlp::Size& size);
 
     void set(const float width = 0, const float height = 0,
              const float depth = 0);
-    void set(const Size& size);
+    void set(const tlp::Size& size);
 
     void setW(const float width);
     void setH(const float height);
