@@ -1,4 +1,14 @@
 //-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 #ifndef _RANDOMLAYOUT_H
 #define _RANDOMLAYOUT_H
 
@@ -18,15 +28,14 @@
  *
  *  \author David Auber University Bordeaux I France, Email : auber@tulip-software.com
  */
-class Random:public Layout
+class Random:public tlp::LayoutAlgorithm
 { 
 public:
-  Random(const PropertyContext &);
+  Random(const tlp::PropertyContext &);
   ~Random();
   
   bool run();
   bool check(std::string &);
-  void reset();
 };
 
 #endif
