@@ -1,4 +1,14 @@
 //-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 #ifndef _TutteLAYOUT_H
 #define _TutteLAYOUT_H
 #include <cmath>
@@ -33,14 +43,13 @@
  *  (at your option) any later version.
  *
 */
-class Tutte:public Layout {
+class Tutte:public tlp::LayoutAlgorithm {
 public:
-  Tutte(const PropertyContext &);
+  Tutte(const tlp::PropertyContext &);
   ~Tutte();
   
   bool run();
   bool check(std::string &);
-  void reset();
 };
 /*@}*/
 #endif
