@@ -1,3 +1,14 @@
+//-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 #ifndef _ARITYMETRIC_H
 #define _ARITYMETRIC_H
 
@@ -12,10 +23,10 @@
  *
  *  - 04/10/2001 Verson 0.0.1: Initial release
  *
- *  \note This plug-ins exists to obtain a uniform interface in the 
- *  Tulip graph viusalization software. To access to the degree
+ *  \note This plug-in exists to obtain a uniform interface in the 
+ *  Tulip graph visualization software. To access to the degree
  *  of a node it is recommended to use directly the degree function
- *  available in each SuperGraph.
+ *  available in each graph.
  *
  *  \author David Auber University Bordeaux I France, Email : auber@tulip-software.org
  *
@@ -27,9 +38,9 @@
  *  (at your option) any later version.
  *
  */
-class ArityMetric:public Metric { 
+class ArityMetric:public tlp::DoubleAlgorithm { 
 public:
-  ArityMetric(const PropertyContext &);
+  ArityMetric(const tlp::PropertyContext &);
   bool run();
 };
 /*@}*/
