@@ -1,11 +1,23 @@
+//-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 #include <iostream>
-#include <tulip/MetaGraphProxy.h>
-#include <tulip/TlpTools.h>
 #include <stack>
 
+#include <tulip/TulipPlugin.h>
+
 using namespace std;
+using namespace tlp;
 //=============================================================================================
-static void bicoTestAndLabeling(const SuperGraph & graph,node v, MutableContainer<int>& compnum,
+static void bicoTestAndLabeling(const Graph & graph,node v, MutableContainer<int>& compnum,
                     MutableContainer<int>& dfsnum, MutableContainer<int>& lowpt,
                     MutableContainer<node>& father,stack<node>& current,
                     int& count1,int& count2) {
@@ -40,7 +52,7 @@ static void bicoTestAndLabeling(const SuperGraph & graph,node v, MutableContaine
   }
 }
 //=============================================================================================
-int biconnectedComponents(const SuperGraph& graph, MutableContainer<int>& compnum) {
+int biconnectedComponents(const Graph& graph, MutableContainer<int>& compnum) {
   stack<node> current;
   MutableContainer<int> dfsnum;
   dfsnum.setAll(-1);
@@ -81,12 +93,12 @@ int biconnectedComponents(const SuperGraph& graph, MutableContainer<int>& compnu
 //=============================================================================================
 #include <tulip/TulipPlugin.h>
 using namespace std;
+using namespace tlp;
 
 /** \addtogroup metric */
 /*@{*/
-/// BicconnectedComponent.h - An implementation of the  biconnected component decompostion algorithm.
-/** This plugin is an implementation of a biconnected component decompostion algorithm. it assigns to 
- *  to all the edge in the same componnent the same value.
+/** This plugin is an implementation of a biconnected component decompostion algorithm. It assigns to 
+ *  the same value to all the edges in the same component.
  *
  *  <b>HISTORY</b>
  *
@@ -108,23 +120,23 @@ using namespace std;
  *  (at your option) any later version.
  *
  */
-class BiconnectedComponnent:public Metric { 
+class BiconnectedComponnent:public DoubleAlgorithm { 
 public:
-  BiconnectedComponnent(const PropertyContext &context):Metric(context){};
+  BiconnectedComponnent(const PropertyContext &context):DoubleAlgorithm(context){};
   bool run() {
     MutableContainer<int> compo;
     compo.setAll(-1);
-    biconnectedComponents(*superGraph, compo);
-    metricProxy->setAllEdgeValue(-1);
-    metricProxy->setAllNodeValue(-1);
-    Iterator<edge> *it = superGraph->getEdges();
+    biconnectedComponents(*graph, compo);
+    doubleResult->setAllEdgeValue(-1);
+    doubleResult->setAllNodeValue(-1);
+    Iterator<edge> *it = graph->getEdges();
     while(it->hasNext()) {
       edge e = it->next();
-      metricProxy->setEdgeValue(e, compo.get(e.id));
+      doubleResult->setEdgeValue(e, compo.get(e.id));
     } delete it;
     return true;
   }
 };
 /*@}*/
 //=============================================================================================
-METRICPLUGINOFGROUP(BiconnectedComponnent,"Biconnected Component","David Auber","03/01/2005","Alpha","0","1","Component");
+DOUBLEPLUGINOFGROUP(BiconnectedComponnent,"Biconnected Component","David Auber","03/01/2005","Alpha","1.0","Component");
