@@ -1,4 +1,14 @@
 //-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 #ifndef _ConnectedComponent_H
 #define _ConnectedComponent_H
 #include <tulip/TulipPlugin.h>
@@ -7,7 +17,7 @@
 /*@{*/
 /// ConnectedComponent.h - An implementation of the connected component algorithm.
 /** This plugin is an implementation of the connected componnent decompostion algorithm. each 
- *  node and edge that belongs to the same componnent receive the same value.
+ *  node and edge that belongs to the same component receive the same value.
  *
  *  <b>HISTORY</b>
  *
@@ -15,8 +25,7 @@
  *
  *
  *  \note This algorithm assigns to each node a value defined as following : If two nodes are in the same
- *  connected component they have the same value else they have a 
- *  different value.
+ *  connected component they have the same value else they have a different value.
  *
  *
  *  \author David Auber University Bordeaux I France: Email:auber@tulip-software.org
@@ -29,14 +38,11 @@
  *  (at your option) any later version.
  *
  */
-class ConnectedComponent:public Metric { 
+class ConnectedComponent:public tlp::DoubleAlgorithm { 
 public:
-  ConnectedComponent(const PropertyContext &);
+  ConnectedComponent(const tlp::PropertyContext &);
   ~ConnectedComponent();
   bool run();
-
-private:
-  void dfs(node n, MutableContainer<bool> &flag,double value);
 };
 /*@}*/
 #endif
