@@ -1,4 +1,14 @@
 //-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 #ifndef _DagLevelMETRIC_H
 #define _DagLevelMETRIC_H
 
@@ -28,9 +38,9 @@
  *  (at your option) any later version.
  *
  */
-class DagLevelMetric:public Metric {
+class DagLevelMetric:public tlp::DoubleAlgorithm {
 public:
-  DagLevelMetric(const PropertyContext &);
+  DagLevelMetric(const tlp::PropertyContext &);
   ~DagLevelMetric();
   bool run();
   bool check(std::string &);
