@@ -1,8 +1,9 @@
 //-*-c++-*-
-/*
- Author: David Auber
- Email : auber@labri.fr
- Last modification : 20/08/2001
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by  
  the Free Software Foundation; either version 2 of the License, or     
@@ -16,8 +17,8 @@
 
 /** \addtogroup metric */
 /*@{*/
-/// IdMetric.h - This plugins assigns id to nodes and edges.
-/** This plugins assigns id to nodes and edges. The id are those used by tulip.
+/// IdDoubleMetric.h - This plugins assigns id to nodes and edges.
+/** This plugins assigns id to nodes and edges. The ids are those used by tulip.
  *
  *  <b>HISTORY</b>
  *
@@ -35,9 +36,9 @@
  *  (at your option) any later version.
  *
  */
-class IdMetric:public Metric { 
+class IdMetric:public tlp::DoubleAlgorithm { 
 public:
-  IdMetric(const PropertyContext &);
+  IdMetric(const tlp::PropertyContext &);
   bool run();
 };
 /*@}*/
@@ -50,8 +51,3 @@ public:
 
 
 
-
-
-
-
-
