@@ -1,4 +1,14 @@
 //-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 #ifndef _LEAFMETRIC_H
 #define _LEAFMETRIC_H
 
@@ -29,13 +39,13 @@
  *  (at your option) any later version.
  *
  */
-class LeafMetric:public Metric { 
+class LeafMetric:public tlp::DoubleAlgorithm { 
 public:
-  LeafMetric(const PropertyContext &);
+  LeafMetric(const tlp::PropertyContext &);
   bool check(std::string &);
   bool run();
 private:
-  double getNodeValue(const node n);
+  double getNodeValue(const tlp::node n);
 };
 /*@}*/
 #endif
