@@ -1,8 +1,9 @@
 //-*-c++-*-
-/*
- Author: David Auber
- Email : auber@labri.fr
- Last modification : 20/08/2001
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by  
  the Free Software Foundation; either version 2 of the License, or     
@@ -14,14 +15,14 @@
 
 #include <tulip/TulipPlugin.h>
 
-class PathLengthMetric:public Metric { 
+class PathLengthMetric:public tlp::DoubleAlgorithm { 
 public:
-  PathLengthMetric(const PropertyContext &);
+  PathLengthMetric(const tlp::PropertyContext &);
   bool run();
   bool check(std::string &);
 private:
-  double getNodeValue(const node n);
-  MetricProxy *leafMetric;
+  double getNodeValue(const tlp::node n);
+  tlp::DoubleProperty* leafMetric;
 };
 
 #endif
