@@ -1,4 +1,14 @@
 //-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 #ifndef _RANDOMMETRIC_H
 #define _RANDOMMETRIC_H
 
@@ -6,7 +16,7 @@
 
 /** \addtogroup metric */
 /*@{*/
-/// RandomhMetric.h - This plugins assigns random values to nodes and edges.
+/// RandomMetric.h - This plugins assigns random values to nodes and edges.
 /** This plugins assigns random values to nodes and edges. the values are between 0 and 1.
  *
  *  <b>HISTORY</b>
@@ -25,9 +35,9 @@
  *  (at your option) any later version.
  *
  */
-class RandomMetric:public Metric { 
+class RandomMetric:public tlp::DoubleAlgorithm { 
 public:
-  RandomMetric(const PropertyContext &);
+  RandomMetric(const tlp::PropertyContext &);
   bool run();
 };
 /*@}*/
