@@ -1,4 +1,14 @@
 //-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 #ifndef Tulip_InducedSubGraphSelection_H
 #define Tulip_InducedSubGraphSelection_H
 
@@ -15,9 +25,9 @@
  *  \author David Auber, LaBRI University Bordeaux I France: 
  *   auber@tulip-software.org
  */
-class InducedSubGraphSelection:public Selection { 
+class InducedSubGraphSelection:public tlp::BooleanAlgorithm { 
 public:
-  InducedSubGraphSelection(const PropertyContext &);
+  InducedSubGraphSelection(const tlp::PropertyContext &);
   bool run();
 };
 /*@}*/
