@@ -1,3 +1,14 @@
+//-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 /**
  Author: David Auber
  Email : auber@labri.fr
@@ -9,22 +20,23 @@
 */
 #include <assert.h>
 #include "MultipleEdgeSelection.h"
-#include <tulip/SelectionProxy.h>
+#include <tulip/BooleanProperty.h>
 #include <tulip/SimpleTest.h>
 
-SELECTIONPLUGIN(MultipleEdgeSelection,"Multiple edge","David Auber","20/01/2003","Alpha","0","1");
+BOOLEANPLUGIN(MultipleEdgeSelection,"Multiple Edge","David Auber","20/01/2003","Alpha","1.0");
 
 using namespace std;
+using namespace tlp;
 
-MultipleEdgeSelection::MultipleEdgeSelection(const PropertyContext &context):Selection(context) {}
+MultipleEdgeSelection::MultipleEdgeSelection(const PropertyContext &context):BooleanAlgorithm(context) {}
 
 bool MultipleEdgeSelection::run() {
   vector<edge> multipleEdges;
-  SimpleTest::simpleTest(superGraph, &multipleEdges);
-  selectionProxy->setAllNodeValue(false);
-  selectionProxy->setAllEdgeValue(false);
+  SimpleTest::simpleTest(graph, &multipleEdges);
+  booleanResult->setAllNodeValue(false);
+  booleanResult->setAllEdgeValue(false);
   vector<edge>::const_iterator it;
   for (it = multipleEdges.begin(); it != multipleEdges.end(); ++it) 
-    selectionProxy->setEdgeValue(*it, true);
+    booleanResult->setEdgeValue(*it, true);
   return true;
 }
