@@ -1,4 +1,14 @@
 //-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 #ifndef Tulip_ParaSelection_H
 #define Tulip_ParaSelection_H
 
@@ -6,7 +16,6 @@
 /** \addtogroup selection */
 /*@{*/
 
-/// This selection plugins enables to find the multiple-edges and parallel-edges in a graph.
 /**
  * This selection plugins enables to find the multiple-edges and parallel-edges in a graph.
  * Let e1, e2 two edges, e1 and e2 are parallel edges if source(e1)=source(e2) and 
@@ -16,9 +25,9 @@
  *  \author David Auber, LaBRI University Bordeaux I France: 
  *   auber@tulip-software.org
  */
-class MultipleEdgeSelection:public Selection { 
+class MultipleEdgeSelection:public tlp::BooleanAlgorithm { 
 public:
-  MultipleEdgeSelection(const PropertyContext &);
+  MultipleEdgeSelection(const tlp::PropertyContext &);
   bool run();
 };
 /*@}*/
