@@ -1,3 +1,14 @@
+//-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -17,22 +28,35 @@
 
 #if defined(__APPLE__)
 #include <libgen.h>
+#include <OpenGL/gl.h>
+#include <OpenGL/glu.h>
+#else
+#include <GL/gl.h>
+#include <GL/glu.h>
 #endif
 
 #include <string.h>
-#include <GL/gl.h>
 #include <GL/osmesa.h>
 
 #include <tulip/TlpTools.h>
 #include <tulip/PluginLoader.h>
-#include <tulip/LayoutProxy.h>
+#include <tulip/LayoutProperty.h>
+#include <tulip/StringProperty.h>
+#include <tulip/ExportModule.h>
+#include <tulip/ImportModule.h>
 #include <tulip/Glyph.h>
-#include <tulip/GlGraph.h>
+#include <tulip/GlScene.h>
+#include <tulip/GlDisplayListManager.h>
+#include <tulip/GlTextureManager.h>
+#include <tulip/GlFeedBackRecorder.h>
+
+#include "GlHTMLFeedBackBuilder.h"
 
 #include "ImageWriter.h"
-#include "Shape.h"
 
 using namespace std;
+using namespace tlp;
+using namespace tlprender;
 //EXIT CODES
 enum EXIT_CODES {LAYOUT_NOTFOUND = 2,
                  LAYOUT_ERROR,
@@ -66,17 +90,24 @@ static void parseCommandLine(int, char **);
 static void help() __attribute__ ((noreturn));
 
 //==============================================================================
-class GLOffscreen: public GlGraph {
+class GLOffscreen {
 private:
   int width,height;
   OSMesaContext osContext;
   GLubyte *buffer;
 public:
+  GlScene scene;
   //GlGraph *glgraph;
   GLOffscreen(const int width=640, const int height=480):
-    GlGraph(),
     width(width), height(height)
   {
+    Vector<int, 4> viewport;
+    viewport[0] = 0;
+    viewport[1] = 0;
+    viewport[2] = width;
+    viewport[3] = height;
+    scene.setViewport(viewport);
+
     buffer = new GLubyte [width * height * 4];
     osContext = OSMesaCreateContext(OSMESA_RGBA, NULL);
     if (!osContext) {
@@ -105,6 +136,11 @@ public:
     glFlush();
   }
 
+  void setupOpenGlContext() {
+    //  cerr << __PRETTY_FUNCTION__ << " (" << (int)this << ")" << endl;
+    makeCurrent();
+  }
+
   void setDoubleBuffering(bool b) {}
 
   bool timerIsActive() {return false;}
@@ -121,23 +157,20 @@ public:
 //==============================================================================
 //a pluginLoader with less output than PluginLoaderTxt
 struct MyPluginLoader:public PluginLoader {
-private:
-  int nbFiles, num;
 public:
   virtual void start(const std::string &path,const std::string &type) {
     cout << "Loading " << type << " plugins: ";
   }
-  virtual void numberOfFile(int nbFile){nbFiles=nbFile; num=0;}
   virtual void loading(const std::string &filename) {}
   virtual void loaded(const std::string &name,
 		      const std::string &author,
 		      const std::string &date, 
 		      const std::string &info,
 		      const std::string &release,
-		      const std::string &version)
+		      const std::string &version,
+		      const std::list <Dependency> &deps)
   {
     cout << "[" << name << "]";
-    //     if (++num < nbFiles) cout << ", ";
   }
   virtual void aborted(const std::string &filename,const  std::string &erreurmsg) {
     //    cout << "Error loading " << filename << ": " << erreurmsg << endl;
@@ -149,175 +182,69 @@ public:
 };
 
 //load software side plugins
-static void loadPlugins(PluginLoader *plug)
+static void loadGlyphPlugins(PluginLoader *plug)
 {
-  string getEnvVar=tlp::TulipLibDir + "/tlp/plugins/";
+  string getEnvVar=tlp::TulipLibDir + "/tlp/";
   
-  GlGraph::glyphFactory->load(getEnvVar + "glyph", "Glyph", plug);
+  tlp::loadPluginsFromDir(getEnvVar + "glyphs", "Glyph", plug);
 }
 
 //==============================================================================
-void importGraph(const string &filename, const string &importPluginName, GlGraph &glGraph)
+void importGraph(const string &filename, const string &importPluginName, GlScene *glScene)
 {
   DataSet dataSet;
 
-  StructDef parameter= ImportModuleFactory::factory->getParam(importPluginName);
+  StructDef parameter=
+    ImportModuleFactory::factory->getPluginParameters(importPluginName);
   Iterator<pair<string,string> > *itP=parameter.getField();
   
   for (;itP->hasNext();) {
     pair<string,string> itp=itP->next();
-    if (itp.first=="filename"){
-      dataSet.set("filename", filename);
+    if (itp.first=="file::filename"){
+      dataSet.set("file::filename", filename);
       continue;
     }
   }delete itP;
   
-  SuperGraph *newSuperGraph=tlp::importGraph(importPluginName, dataSet, NULL);
-  
-  if (newSuperGraph!=0) {
-    glGraph.setSuperGraph(newSuperGraph);
-    LayoutProxy *layout = glGraph.getSuperGraph()->getProperty<LayoutProxy>("viewLayout");
-    layout->resetBoundingBox();
-    layout->center();
-    layout->notifyObservers();
-    glGraph.centerScene();
+  //Graph *newGraph=tlp::importGraph(importPluginName, dataSet, NULL);
+  //Graph *newGraph=tlp::loadGraph(filename);
+  Graph *newGraph = tlp::newGraph();
+  tlp::importGraph(importPluginName, dataSet, NULL,newGraph);
+
+  if (newGraph!=0) {
+    string sceneData;
+    dataSet.get<std::string>("scene", sceneData);
+
+    if(!sceneData.empty()) {
+      string dir=TulipLibDir;
+      string name="TulipLibDir";
+      while(sceneData.find(name)!=-1) {
+	int pos=sceneData.find(name);
+	sceneData.replace(pos,name.length(),dir);
+      }
+      glScene->setWithXML(sceneData,newGraph);
+    } else {
+      GlGraphComposite* glGraphComposite = new GlGraphComposite(newGraph);
+      GlLayer *layer = new GlLayer("Main");
+      glScene->addLayer(layer);
+      glScene->addGlGraphCompositeInfo(glScene->getLayer("Main"),glGraphComposite);
+      glScene->getLayer("Main")->addGlEntity(glGraphComposite,"graph");
+      
+      LayoutProperty *layout =
+	newGraph->getProperty<LayoutProperty>("viewLayout");
+      layout->resetBoundingBox();
+      layout->center();
+      layout->notifyObservers();
+    }
+    glScene->centerScene();
+    GlGraphRenderingParameters param =glScene->getGlGraphComposite()->getRenderingParameters();
     DataSet glGraphData;
-    if (dataSet.get<DataSet>("displaying", glGraphData))
-      glGraph.setParameters(glGraphData);
+    if (dataSet.get<DataSet>("displaying", glGraphData)) {
+      param.setParameters(glGraphData);
+      glScene->getGlGraphComposite()->setRenderingParameters(param);
+    }
   }
 }
-//==============================================================================
-/*
- *
- */
-void outputPolygons(const int size, const GlGraph &glgraph)
-{
-  priority_queue<tlprender::Shape *> shapeQueue;
-  ofstream of((filename+".html").c_str(), ios::out | ios::trunc);
-  string filenameBase(basename(filename.c_str()));
-  
-  bool drawingNodes=false, inNode=false;
-  GLint token, count = size, n, x, y;
-  GLfloat z;
-  GLfloat val=0.0;
-  tlprender::Shape *poly=NULL;
-
-  cerr << __PRETTY_FUNCTION__ << ": size=" << size << endl;
-  while (count) {
-    token = (GLint) buffer[size-count]; count--;
-    switch(token) {
-    case GL_PASS_THROUGH_TOKEN:
-      /*
-       * val < 0: then it is a marker: -1 => entering/leaving node rendering
-       * val > 0: node number rendered in node mode. This marker occurs each time a new node has been rendered;
-       *          NODE 1 ... POLY ... POLY ... POLY ... NODE 2 ... POLY ...
-       *	  To clip all polygons of node 1 in one Shape clip them from node 1's marker until you
-       *          seek the node 2's marker.
-       */
-      val = buffer[size-count]; count--;
-      if (val == -1.0) drawingNodes = !drawingNodes;
-      else if (val >= 0.0) {
- 	inNode = !inNode;
- 	if (!inNode) {
- 	}
- 	else {
- 	  if (poly!=NULL) {
-            if (poly->isValid()) shapeQueue.push(poly);
-            else delete poly;
-          }
- 	  poly = new tlprender::Shape();
-	}
-      }
-#ifndef NDEBUG
-      if (val <= 0.0)
-        cerr << "GL_PASS_THROUGH_TOKEN: val=" << dec << val << ", drawingNodes=" << drawingNodes << endl;
-#endif
-      break;
-    case GL_POINT_TOKEN: count--; break;
-    case GL_LINE_TOKEN: count -= 6; break;
-    case GL_LINE_RESET_TOKEN: count -=6; break;
-    case GL_POLYGON_TOKEN: {
-      n = (GLint) buffer[size-count]; count--;
-      if (drawingNodes) {
-	tlprender::Shape *tmp = new tlprender::Shape();
-        tmp->begin();
-	for (int i=0; i<n; ++i) {
-	  x = (GLint) buffer[size-count]; count--;
-	  y = height - (GLint) buffer[size-count]; count--;
-	  z = buffer[size-count]; count--;
-	  tmp->add(x,y,z);
-	}
-	if (tmp->end()) {
-	  if (!poly->clip(*tmp)) {
-            poly->nodeNum=(unsigned int) val;
-            if (poly->isValid()) shapeQueue.push(poly);
-            else delete poly;
-            poly=tmp;
-          }
-          else delete tmp;
-        }
-      } //endif (drawingNodes)
-      else {
-        count -= (n * 3);        
-      }
-      break;
-    }
-    case GL_BITMAP_TOKEN: count -=3; break;
-    case GL_DRAW_PIXEL_TOKEN: count -=3; break;
-    case GL_COPY_PIXEL_TOKEN: count -=3; break;
-    default:
-#ifndef NDEBUG
-      cerr << __PRETTY_FUNCTION__ << ": count=" << count << ", unexpected token: " << hex << token << dec << endl;
-#endif
-      break;
-    } //end switch(token)
-  } //end while(count)
-
-  /* write HTML AREA MAP */
-  StringProxy *hrefp = glgraph.getSuperGraph()->getProperty<StringProxy>("href");
-  StringProxy *altp = glgraph.getSuperGraph()->getProperty<StringProxy>("alt");
-
-  if (outputHtmlBody) {
-    of << "<html><body>" << endl;
-  }
-  
-  of << "<img src=\"" << filenameBase << "." << imageFormat << "\" usemap=\"#usemap\" border=\"0\" ";
-  of << "width=\"" << width << "\" height=\"" << height << "\">" << endl;
-  of << "<map name=\"usemap\">" << endl;
-
-  while (!shapeQueue.empty()) {
-    const tlprender::Shape *s = shapeQueue.top();
-    string href = hrefp->getNodeValue(node(s->nodeNum));
-#ifndef NDEBUG
-    if (href=="") {
-      stringstream ss;
-      ss << "javascript:alert(\'node " << s->nodeNum << "\')";
-      href = ss.str();
-    }
-#endif
-    string alt = altp->getNodeValue(node(s->nodeNum));
-#ifdef NDEBUG
-    if (alt=="") {
-      stringstream ss;
-      ss << "node " << s->nodeNum;
-      alt = ss.str();
-    }
-#endif
-    of << "    <area href=\"" << href << "\" alt=\"" << alt << "\"" << endl;
-    of << "          shape=\"poly\" coords=\"" << *s << "\">" << endl;
-    delete s;
-    shapeQueue.pop();
-  }
-  
-  of << "</map>" << endl;
-  
-  if (outputHtmlBody) {
-    of << "</body></html>" << endl;
-  }
-  
-  of.close();
-}
-
 /***************************************************************************************************/
 int main (int argc, char **argv) {
 
@@ -328,18 +255,20 @@ int main (int argc, char **argv) {
   MyPluginLoader plug;
   tlp::initTulipLib();
   tlp::loadPlugins(&plug);   // library side plugins
-  loadPlugins(&plug);   // software side plugins, i.e. glyphs
+  loadGlyphPlugins(&plug);   // software side plugins, i.e. glyphs
 
   GLOffscreen glOffscreen(width, height);
 
-  importGraph(graphFile, importPluginName, glOffscreen);
+  importGraph(graphFile, importPluginName, &glOffscreen.scene);
   
+  Graph *graph=glOffscreen.scene.getGlGraphComposite()->getInputData()->getGraph();
+
   if (layoutSpecified) {
-    bool resultBool=false, cached=false;
+    bool resultBool=false;
     string errorMsg;
-    if (LayoutProxy::factory->exists(layoutName)) {
-      LayoutProxy *myLayout = glOffscreen.getSuperGraph()->getProperty<LayoutProxy>("viewLayout");
-      resultBool = glOffscreen.getSuperGraph()->computeProperty(layoutName, myLayout, errorMsg);
+    if (LayoutProperty::factory->pluginExists(layoutName)) {
+      LayoutProperty *myLayout = graph->getProperty<LayoutProperty>("viewLayout");
+      resultBool = graph->computeProperty(layoutName, myLayout, errorMsg);
       if (!resultBool) {
         cerr << programName << ": layout error, reason: " << errorMsg << endl;
         exit(LAYOUT_ERROR);
@@ -348,7 +277,7 @@ int main (int argc, char **argv) {
         myLayout->resetBoundingBox();
         myLayout->center();
         myLayout->notifyObservers();
-        glOffscreen.centerScene();
+        glOffscreen.scene.centerScene();
       }
     }
     else {
@@ -357,8 +286,19 @@ int main (int argc, char **argv) {
     }
   }
   
-  glOffscreen.setIncrementalRendering(false);
-  glOffscreen.draw();
+  glOffscreen.setupOpenGlContext();
+  glOffscreen.updateGL();
+
+  GlDisplayListManager::getInst().changeContext(0);
+  GlTextureManager::getInst().changeContext(0);
+
+  GlGraphRenderingParameters params = glOffscreen.scene.getGlGraphComposite()->getRenderingParameters();
+  params.setIncrementalRendering(false);
+  glOffscreen.scene.getGlGraphComposite()->setRenderingParameters(params);
+  glOffscreen.scene.draw();
+
+  glOffscreen.setupOpenGlContext();
+  glOffscreen.updateGL();
 
   //write image
   imageWriter = tlprender::ImageWriter::getImageWriter(imageFormat, glOffscreen.getImageBuffer(), width, height);
@@ -379,29 +319,53 @@ int main (int argc, char **argv) {
   
   //create HTML map
   if (outputMap) {
+    ofstream of((filename+".html").c_str(), ios::out | ios::trunc);
     buffer = new GLfloat[BUFFERSIZE];
     glFeedbackBuffer(BUFFERSIZE, GL_3D, buffer);
     glRenderMode(GL_FEEDBACK);
-    glOffscreen.draw();
+    glOffscreen.scene.getGlGraphComposite()->getInputData()->parameters->setFeedbackRender(true);
+    glOffscreen.scene.draw();
+    
+    glFlush();
+    glFinish();
 
     int size = glRenderMode(GL_RENDER);
     if (size < 0) {
       cerr << programName << ": Problem during Feedback mode. Cannot compute HTML page" << endl;
       exit(HTML_ERROR);
     }
-    else  outputPolygons(size, glOffscreen);
+    else{
+      StringProperty *hrefp = glOffscreen.scene.getGlGraphComposite()->getInputData()->getGraph()->getProperty<StringProperty>("href");
+      StringProperty *altp = glOffscreen.scene.getGlGraphComposite()->getInputData()->getGraph()->getProperty<StringProperty>("alt");
+
+      GlHTMLFeedBackBuilder builder(false,filename+"."+imageFormat,hrefp,altp);
+      GlFeedBackRecorder recorder(&builder,3);
+      Vector<int, 4> viewport;
+      viewport[0] = 0;
+      viewport[1] = 0;
+      viewport[2] = width;
+      viewport[3] = height;
+      
+      builder.begin(viewport,NULL,0,0);
+      recorder.record(false,size,buffer,viewport);
+      string str;
+      builder.getResult(&str);
+      of << str ;
+    }
     
+    of.close();
     delete[] buffer;
   }
 
   if (saveTLP) {
     DataSet dataSet;
     ostream *os = new ofstream(saveTLPFile.c_str());
-    StructDef parameter = ExportModuleFactory::factory->getParam("tlp");
+    StructDef parameter =
+      ExportModuleFactory::factory->getPluginParameters("tlp");
 
-    dataSet.set("displaying", glOffscreen.getParameters());
+    dataSet.set("displaying", glOffscreen.scene.getGlGraphComposite()->getRenderingParameters().getParameters());
 
-    if (!tlp::exportGraph(glOffscreen.getSuperGraph(), *os, "tlp", dataSet, NULL)) {
+    if (!tlp::exportGraph(glOffscreen.scene.getGlGraphComposite()->getInputData()->getGraph(), *os, "tlp", dataSet, NULL)) {
       cerr << programName << ": saving graph to \"" << saveTLPFile << "\" failed. Exiting" << endl;
       return EXIT_FAILURE;
     }
