@@ -1,3 +1,14 @@
+//-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -9,21 +20,20 @@
 
 using namespace std;
 
-#if (QT_REL == 4)
-Application *qApp = (Application *) NULL;
-#endif
-
 //**********************************************************************
 Application::Application(int& argc, char ** argv): QApplication(argc,argv) 
 {
-  qApp = this;
-  tlp::initTulipLib((char *) QApplication::applicationDirPath().ascii());
+#if defined(__APPLE__)
+  // allows to load qt imageformats plugin
+  QApplication::addLibraryPath(QApplication::applicationDirPath() + "/..");
+#endif
+  tlp::initTulipLib((char *) QApplication::applicationDirPath().toAscii().data());
   string::const_iterator begin=tlp::TulipPluginsPath.begin();
   string::const_iterator end=begin;
   while (end!=tlp::TulipPluginsPath.end())
     if ((*end)==tlp::PATH_DELIMITER) {
       if (begin!=end) {
-	string path = string(begin,end) + "/../bitmaps/";
+	string path = string(begin,end) + "/bitmaps/";
 	QDir *bitmapsDir= new QDir(path.c_str());
 	if(bitmapsDir->exists()) {
 	  bitmapPath = path.c_str();
@@ -38,7 +48,7 @@ Application::Application(int& argc, char ** argv): QApplication(argc,argv)
     else
       ++end;
   if (begin!=end) {
-    string path = string(begin,end) + "/../bitmaps/";
+    string path = string(begin,end) + "/bitmaps/";
     QDir *bitmapsDir= new QDir(path.c_str());
     if(bitmapsDir->exists()) {
       bitmapPath = path.c_str();
