@@ -1,3 +1,14 @@
+//-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 #include "FTFace.h"
 #include "FTCharmap.h"
 
@@ -44,17 +55,15 @@ bool FTCharmap::CharMap( FT_Encoding encoding)
 }
 
 
-unsigned int FTCharmap::CharIndex( unsigned int characterCode )
+unsigned int FTCharmap::GlyphListIndex( unsigned int characterCode )
 {
-    const CharacterMap::GlyphIndex *result = charMap.find( characterCode);
-    if( !result)
-    {
-        return 0;
-    }
-    else
-    {
-        return *result;
-    }
+    return charMap.find( characterCode);
+}
+
+
+unsigned int FTCharmap::FontIndex( unsigned int characterCode )
+{
+    return FT_Get_Char_Index( ftFace, characterCode);
 }
 
 
@@ -62,10 +71,3 @@ void FTCharmap::InsertIndex( const unsigned int characterCode, const unsigned in
 {
     charMap.insert( characterCode, containerIndex);
 }
-
-
-unsigned int FTCharmap::GlyphIndex( const unsigned int characterCode)
-{
-    unsigned int glyphIndex = FT_Get_Char_Index( ftFace, characterCode);
-    return glyphIndex;
-}
