@@ -1,11 +1,23 @@
+//-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 #include    "FTFace.h"
 #include    "FTFont.h"
 #include    "FTGlyphContainer.h"
 #include    "FTBBox.h"
 
 
-FTFont::FTFont( const char* fontname)
-:   face( fontname),
+FTFont::FTFont( const char* fontFilePath)
+:   face( fontFilePath),
+    useDisplayLists(true),
     glyphList(0)
 {
     err = face.Error();
@@ -34,9 +46,9 @@ FTFont::~FTFont()
 }
 
 
-bool FTFont::Attach( const char* filename)
+bool FTFont::Attach( const char* fontFilePath)
 {
-    if( face.Attach( filename))
+    if( face.Attach( fontFilePath))
     {
         err = 0;
         return true;
@@ -66,15 +78,19 @@ bool FTFont::Attach( const unsigned char *pBufferBytes, size_t bufferSizeInBytes
 
 bool FTFont::FaceSize( const unsigned int size, const unsigned int res )
 {
-	charSize = face.Size( size, res);
-    if( face.Error())
+    charSize = face.Size( size, res);
+    err = face.Error();
+    
+    if( err != 0)
     {
         return false;
     }
-    if( glyphList)
+    
+    if( glyphList != NULL)
     {
         delete glyphList;
     }
+    
     glyphList = new FTGlyphContainer( &face);
     return true;
 }
@@ -94,6 +110,23 @@ bool FTFont::CharMap( FT_Encoding encoding)
 }
 
 
+unsigned int FTFont::CharMapCount()
+{
+    return face.CharMapCount();
+}
+
+
+FT_Encoding* FTFont::CharMapList()
+{
+    return face.CharMapList();
+}
+
+
+void FTFont::UseDisplayList( bool useList)
+{
+    useDisplayLists = useList;
+}
+
 float FTFont::Ascender() const
 {
     return charSize.Ascender();
@@ -105,6 +138,10 @@ float FTFont::Descender() const
     return charSize.Descender();
 }
 
+float FTFont::LineHeight() const
+{
+    return charSize.Height();
+}
 
 void FTFont::BBox( const char* string,
                    float& llx, float& lly, float& llz, float& urx, float& ury, float& urz)
@@ -114,21 +151,23 @@ void FTFont::BBox( const char* string,
     if((NULL != string) && ('\0' != *string))
     {
         const unsigned char* c = (unsigned char*)string;
+        float advance = 0;
 
-        CheckGlyph( *c);
-
-        totalBBox = glyphList->BBox( *c);
-        float advance = glyphList->Advance( *c, *(c + 1));
-        ++c;
-            
-        while( *c)
+        if(CheckGlyph( *c))
         {
-            CheckGlyph( *c);
-            FTBBox tempBBox = glyphList->BBox( *c);
-            tempBBox.Move( FTPoint( advance, 0.0f, 0.0f));
-            totalBBox += tempBBox;
-            advance += glyphList->Advance( *c, *(c + 1));
-            ++c;
+            totalBBox = glyphList->BBox( *c);
+            advance = glyphList->Advance( *c, *(c + 1));
+        }
+                
+        while( *++c)
+        {
+            if(CheckGlyph( *c))
+            {
+                FTBBox tempBBox = glyphList->BBox( *c);
+                tempBBox.Move( FTPoint( advance, 0.0f, 0.0f));
+                totalBBox += tempBBox;
+                advance += glyphList->Advance( *c, *(c + 1));
+            }
         }
     }
 
@@ -149,21 +188,23 @@ void FTFont::BBox( const wchar_t* string,
     if((NULL != string) && ('\0' != *string))
     {
         const wchar_t* c = string;
+        float advance = 0;
 
-        CheckGlyph( *c);
-
-        totalBBox = glyphList->BBox( *c);
-        float advance = glyphList->Advance( *c, *(c + 1));
-        ++c;
-
-        while( *c)
+        if(CheckGlyph( *c))
         {
-            CheckGlyph( *c);
-            FTBBox tempBBox = glyphList->BBox( *c);
-            tempBBox.Move( FTPoint( advance, 0.0f, 0.0f));
-            totalBBox += tempBBox;
-            advance += glyphList->Advance( *c, *(c + 1));
-            ++c;
+            totalBBox = glyphList->BBox( *c);
+            advance = glyphList->Advance( *c, *(c + 1));
+        }
+        
+        while( *++c)
+        {
+            if(CheckGlyph( *c))
+            {
+                FTBBox tempBBox = glyphList->BBox( *c);
+                tempBBox.Move( FTPoint( advance, 0.0f, 0.0f));
+                totalBBox += tempBBox;
+                advance += glyphList->Advance( *c, *(c + 1));
+            }
         }
     }
 
@@ -183,11 +224,13 @@ float FTFont::Advance( const wchar_t* string)
 
     while( *c)
     {
-        CheckGlyph( *c);
-        width += glyphList->Advance( *c, *(c + 1));
+        if(CheckGlyph( *c))
+        {
+            width += glyphList->Advance( *c, *(c + 1));
+        }
         ++c;
     }
-
+    
     return width;
 }
 
@@ -199,8 +242,10 @@ float FTFont::Advance( const char* string)
 
     while( *c)
     {
-        CheckGlyph( *c);
-        width += glyphList->Advance( *c, *(c + 1));
+        if(CheckGlyph( *c))
+        {
+            width += glyphList->Advance( *c, *(c + 1));
+        }
         ++c;
     }
     
@@ -211,11 +256,14 @@ float FTFont::Advance( const char* string)
 void FTFont::Render( const char* string )
 {
     const unsigned char* c = (unsigned char*)string;
-    pen.x = 0; pen.y = 0;
+    pen.X(0); pen.Y(0);
 
     while( *c)
     {
-        DoRender( *c, *(c + 1));
+        if(CheckGlyph( *c))
+        {
+            pen = glyphList->Render( *c, *(c + 1), pen);
+        }
         ++c;
     }
 }
@@ -224,33 +272,37 @@ void FTFont::Render( const char* string )
 void FTFont::Render( const wchar_t* string )
 {
     const wchar_t* c = string;
-    pen.x = 0; pen.y = 0;
+    pen.X(0); pen.Y(0);
 
     while( *c)
     {
-        DoRender( *c, *(c + 1));
+        if(CheckGlyph( *c))
+        {
+            pen = glyphList->Render( *c, *(c + 1), pen);
+        }
         ++c;
     }
 }
 
 
-void FTFont::DoRender( const unsigned int chr, const unsigned int nextChr)
-{
-    CheckGlyph( chr);
-
-    FTPoint kernAdvance = glyphList->Render( chr, nextChr, pen);
-    
-    pen.x += kernAdvance.x;
-    pen.y += kernAdvance.y;
-}
-
-
-void FTFont::CheckGlyph( const unsigned int characterCode)
+bool FTFont::CheckGlyph( const unsigned int characterCode)
 {
     if( NULL == glyphList->Glyph( characterCode))
     {
-        unsigned int glyphIndex = glyphList->GlyphIndex( characterCode);
-        glyphList->Add( MakeGlyph( glyphIndex), characterCode);
+        unsigned int glyphIndex = glyphList->FontIndex( characterCode);
+        FTGlyph* tempGlyph = MakeGlyph( glyphIndex);
+        if( NULL == tempGlyph)
+        {
+            if( 0 == err)
+            {
+                err = 0x13;
+            }
+            
+            return false;
+        }
+        glyphList->Add( tempGlyph, characterCode);
     }
+    
+    return true;
 }
 
