@@ -1,9 +1,20 @@
+//-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 #include "FTGLBitmapFont.h"
 #include "FTBitmapGlyph.h"
 
 
-FTGLBitmapFont::FTGLBitmapFont( const char* fontname)
-:   FTFont( fontname)
+FTGLBitmapFont::FTGLBitmapFont( const char* fontFilePath)
+:   FTFont( fontFilePath)
 {}
 
 
@@ -18,11 +29,11 @@ FTGLBitmapFont::~FTGLBitmapFont()
 
 FTGlyph* FTGLBitmapFont::MakeGlyph( unsigned int g)
 {
-    FT_Glyph* ftGlyph = face.Glyph( g, FT_LOAD_DEFAULT);
+    FT_GlyphSlot ftGlyph = face.Glyph( g, FT_LOAD_DEFAULT);
 
     if( ftGlyph)
     {
-        FTBitmapGlyph* tempGlyph = new FTBitmapGlyph( *ftGlyph);
+        FTBitmapGlyph* tempGlyph = new FTBitmapGlyph( ftGlyph);
         return tempGlyph;
     }
 
