@@ -1,3 +1,14 @@
+//-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 #ifndef     __FTPixmapGlyph__
 #define     __FTPixmapGlyph__
 
@@ -24,7 +35,7 @@ class  FTGL_EXPORT FTPixmapGlyph : public FTGlyph
          *
          * @param glyph The Freetype glyph to be processed
          */
-        FTPixmapGlyph( FT_Glyph glyph);
+        FTPixmapGlyph( FT_GlyphSlot glyph);
 
         /**
          * Destructor
@@ -37,7 +48,7 @@ class  FTGL_EXPORT FTPixmapGlyph : public FTGlyph
          * @param pen   The current pen position.
          * @return      The advance distance for this glyph.
          */
-        virtual float Render( const FTPoint& pen);
+        virtual const FTPoint& Render( const FTPoint& pen);
         
         // attributes
 
