@@ -1,3 +1,14 @@
+//-*-c++-*-
+/**
+ Authors: David Auber, Patrick Mary, Morgan Mathiaut
+ from the LaBRI Visualization Team
+ Email : auber@tulip-software.org
+ Last modification : 13/03/2009 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by  
+ the Free Software Foundation; either version 2 of the License, or     
+ (at your option) any later version.
+*/
 #include    "FTVectoriser.h"
 #include    "FTGL.h"
 
@@ -5,8 +16,14 @@
 #define CALLBACK
 #endif
 
-#ifdef __APPLE_CC__    
+#ifdef __APPLE_CC__
+  #if __APPLE_CC__ < 5400
+// Tiger
     typedef GLvoid (*GLUTesselatorFunction)(...);
+    #else
+// Leopard
+    typedef GLvoid (*GLUTesselatorFunction)();
+  #endif
 #elif defined( __mips ) || defined( __linux__ ) || defined( __FreeBSD_kernel__) || defined( __FreeBSD__ ) || defined( __OpenBSD__ ) || defined( __sun ) || defined (__CYGWIN__)
     typedef GLvoid (*GLUTesselatorFunction)();
 #elif defined ( WIN32)
