@@ -13,9 +13,14 @@
  * added normal vectors Linas, October 1991
  * "code complete" (that is, I'm done), Linas Vepstas, October 1991
  * work around OpenGL's lack of support for concave polys, June 1994
+ *
+ * Copyright (C) 1991,1994,2003 Linas Vepstas <linas@linas.org>
  */
 
 
+#ifndef __STDC__
+#include <malloc.h>
+#endif
 #include <math.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -69,6 +74,8 @@
  * Linas Vepstas March 1993
  */
 
+#ifndef COLOR_SIGNATURE
+
 /* ============================================================ */
 
 void draw_angle_style_front_cap (int ncp,	/* number of contour points */
@@ -106,8 +113,8 @@ void draw_angle_style_front_cap (int ncp,	/* number of contour points */
    N3F(bi);
 
    tobj = gluNewTess ();
-   gluTessCallback (tobj, GLU_BEGIN, glBegin);
-   gluTessCallback (tobj, GLU_VERTEX, glVertex3dv);
+   gluTessCallback (tobj, GLU_BEGIN, (GLvoid(*))glBegin);
+   gluTessCallback (tobj, GLU_VERTEX, (GLvoid(*))glVertex3dv);
    gluTessCallback (tobj, GLU_END, glEnd);
 
 #ifdef LENIENT_TESSELATOR 
@@ -185,8 +192,8 @@ void draw_angle_style_back_cap (int ncp,	/* number of contour points */
    N3F (bi);
 
    tobj = gluNewTess ();
-   gluTessCallback (tobj, GLU_BEGIN, glBegin);
-   gluTessCallback (tobj, GLU_VERTEX, glVertex3dv);
+   gluTessCallback (tobj, GLU_BEGIN, (GLvoid(*))glBegin);
+   gluTessCallback (tobj, GLU_VERTEX, (GLvoid(*))glVertex3dv);
    gluTessCallback (tobj, GLU_END, glEnd);
 
 #ifdef LENIENT_TESSELATOR 
@@ -222,6 +229,8 @@ void draw_angle_style_back_cap (int ncp,	/* number of contour points */
 #endif /* OPENGL_10 */
 }
 
+#endif /* COLOR_SIGNATURE */
+
 /* ============================================================ */
 
 void extrusion_angle_join (int ncp,		/* number of contour points */
@@ -230,7 +239,7 @@ void extrusion_angle_join (int ncp,		/* number of contour points */
                            gleDouble up[3],	/* up vector for contour */
                            int npoints,		/* numpoints in poly-line */
                            gleDouble point_array[][3],	/* polyline */
-                           float color_array[][3],	/* color of polyline */
+                           gleColor color_array[],	/* color of polyline */
                            gleDouble xform_array[][2][3])  /* 2D contour xforms */
 {
    int i, j;
